from .....Internal.Core import Core
from .....Internal.CommandsGroup import CommandsGroup
from .....Internal import Conversions


# noinspection PyPep8Naming,PyAttributeOutsideInit,SpellCheckingInspection
class Marker:
	"""Marker commands group definition. 4 total commands, 1 Subgroups, 2 group commands"""

	def __init__(self, core: Core, parent):
		self._core = core
		self._cmd_group = CommandsGroup("marker", core, parent)

	@property
	def scenario(self):
		"""scenario commands group. 0 Sub-classes, 2 commands."""
		if not hasattr(self, '_scenario'):
			from .Scenario import Scenario
			self._scenario = Scenario(self._core, self._cmd_group)
		return self._scenario

	def get_enable(self) -> bool:
		"""SCPI: SCENario:OUTPut:MARKer:ENABle \n
		Snippet: value: bool = driver.scenario.output.marker.get_enable() \n
		Enables that markers are considered by the generation of the output waveform file. \n
			:return: enable: ON| OFF| 1| 0
		"""
		response = self._core.io.query_str('SCENario:OUTPut:MARKer:ENABle?')
		return Conversions.str_to_bool(response)

	def set_enable(self, enable: bool) -> None:
		"""SCPI: SCENario:OUTPut:MARKer:ENABle \n
		Snippet: driver.scenario.output.marker.set_enable(enable = False) \n
		Enables that markers are considered by the generation of the output waveform file. \n
			:param enable: ON| OFF| 1| 0
		"""
		param = Conversions.bool_to_str(enable)
		self._core.io.write(f'SCENario:OUTPut:MARKer:ENABle {param}')

	def get_flags(self) -> float:
		"""SCPI: SCENario:OUTPut:MARKer:FLAGs \n
		Snippet: value: float = driver.scenario.output.marker.get_flags() \n
		Enables up to four markers. \n
			:return: flags: int Binary value, where: M1 = 1 M1 = 2 M1 = 4 M1 = 8 Range: 0 to 15
		"""
		response = self._core.io.query_str('SCENario:OUTPut:MARKer:FLAGs?')
		return Conversions.str_to_float(response)

	def set_flags(self, flags: float) -> None:
		"""SCPI: SCENario:OUTPut:MARKer:FLAGs \n
		Snippet: driver.scenario.output.marker.set_flags(flags = 1.0) \n
		Enables up to four markers. \n
			:param flags: int Binary value, where: M1 = 1 M1 = 2 M1 = 4 M1 = 8 Range: 0 to 15
		"""
		param = Conversions.decimal_value_to_str(flags)
		self._core.io.write(f'SCENario:OUTPut:MARKer:FLAGs {param}')

	def clone(self) -> 'Marker':
		"""Clones the group by creating new object from it and its whole existing subgroups
		Also copies all the existing default Repeated Capabilities setting,
		which you can change independently without affecting the original group"""
		new_group = Marker(self._core, self._cmd_group.parent)
		self._cmd_group.synchronize_repcaps(new_group)
		return new_group



from ....Internal.Core import Core
from ....Internal.CommandsGroup import CommandsGroup
from ....Internal import Conversions


# noinspection PyPep8Naming,PyAttributeOutsideInit,SpellCheckingInspection
class Horn:
	"""Horn commands group definition. 2 total commands, 0 Subgroups, 2 group commands"""

	def __init__(self, core: Core, parent):
		self._core = core
		self._cmd_group = CommandsGroup("horn", core, parent)

	def get_lx(self) -> float:
		"""SCPI: ANTenna:MODel:HORN:LX \n
		Snippet: value: float = driver.antenna.model.horn.get_lx() \n
		Sets the length of the rectangular sides of the Pyramidal Horn antenna. \n
			:return: lx: No help available
		"""
		response = self._core.io.query_str('ANTenna:MODel:HORN:LX?')
		return Conversions.str_to_float(response)

	def set_lx(self, lx: float) -> None:
		"""SCPI: ANTenna:MODel:HORN:LX \n
		Snippet: driver.antenna.model.horn.set_lx(lx = 1.0) \n
		Sets the length of the rectangular sides of the Pyramidal Horn antenna. \n
			:param lx: float Range: 0.01 to 100, Unit: m
		"""
		param = Conversions.decimal_value_to_str(lx)
		self._core.io.write(f'ANTenna:MODel:HORN:LX {param}')

	def get_lz(self) -> float:
		"""SCPI: ANTenna:MODel:HORN:LZ \n
		Snippet: value: float = driver.antenna.model.horn.get_lz() \n
		Sets the length of the rectangular sides of the Pyramidal Horn antenna. \n
			:return: lz: float Range: 0.01 to 100, Unit: m
		"""
		response = self._core.io.query_str('ANTenna:MODel:HORN:LZ?')
		return Conversions.str_to_float(response)

	def set_lz(self, lz: float) -> None:
		"""SCPI: ANTenna:MODel:HORN:LZ \n
		Snippet: driver.antenna.model.horn.set_lz(lz = 1.0) \n
		Sets the length of the rectangular sides of the Pyramidal Horn antenna. \n
			:param lz: float Range: 0.01 to 100, Unit: m
		"""
		param = Conversions.decimal_value_to_str(lz)
		self._core.io.write(f'ANTenna:MODel:HORN:LZ {param}')



from ...Internal.Core import Core
from ...Internal.CommandsGroup import CommandsGroup
from ...Internal import Conversions
from ... import enums


# noinspection PyPep8Naming,PyAttributeOutsideInit,SpellCheckingInspection
class Sin:
	"""Sin commands group definition. 6 total commands, 0 Subgroups, 6 group commands"""

	def __init__(self, core: Core, parent):
		self._core = core
		self._cmd_group = CommandsGroup("sin", core, parent)

	def get_height(self) -> float:
		"""SCPI: SCAN:SIN:HEIGht \n
		Snippet: value: float = driver.scan.sin.get_height() \n
		Sets the amplitude of the sine wave. \n
			:return: height: float Range: 1 to 90
		"""
		response = self._core.io.query_str('SCAN:SIN:HEIGht?')
		return Conversions.str_to_float(response)

	def set_height(self, height: float) -> None:
		"""SCPI: SCAN:SIN:HEIGht \n
		Snippet: driver.scan.sin.set_height(height = 1.0) \n
		Sets the amplitude of the sine wave. \n
			:param height: float Range: 1 to 90
		"""
		param = Conversions.decimal_value_to_str(height)
		self._core.io.write(f'SCAN:SIN:HEIGht {param}')

	def get_inversion(self) -> bool:
		"""SCPI: SCAN:SIN:INVersion \n
		Snippet: value: bool = driver.scan.sin.get_inversion() \n
		Sets whether the upper or the down (mirrored) sine wave is used first. \n
			:return: inversion: ON| OFF| 1| 0 OFF Upper sine first ON Down sine first
		"""
		response = self._core.io.query_str('SCAN:SIN:INVersion?')
		return Conversions.str_to_bool(response)

	def set_inversion(self, inversion: bool) -> None:
		"""SCPI: SCAN:SIN:INVersion \n
		Snippet: driver.scan.sin.set_inversion(inversion = False) \n
		Sets whether the upper or the down (mirrored) sine wave is used first. \n
			:param inversion: ON| OFF| 1| 0 OFF Upper sine first ON Down sine first
		"""
		param = Conversions.bool_to_str(inversion)
		self._core.io.write(f'SCAN:SIN:INVersion {param}')

	def get_rate(self) -> float:
		"""SCPI: SCAN:SIN:RATE \n
		Snippet: value: float = driver.scan.sin.get_rate() \n
		Sets the turning speed. \n
			:return: rate: float Range: 0.01 to 100000, Unit: degree/s
		"""
		response = self._core.io.query_str('SCAN:SIN:RATE?')
		return Conversions.str_to_float(response)

	def set_rate(self, rate: float) -> None:
		"""SCPI: SCAN:SIN:RATE \n
		Snippet: driver.scan.sin.set_rate(rate = 1.0) \n
		Sets the turning speed. \n
			:param rate: float Range: 0.01 to 100000, Unit: degree/s
		"""
		param = Conversions.decimal_value_to_str(rate)
		self._core.io.write(f'SCAN:SIN:RATE {param}')

	# noinspection PyTypeChecker
	def get_rotation(self) -> enums.Rotation:
		"""SCPI: SCAN:SIN:ROTation \n
		Snippet: value: enums.Rotation = driver.scan.sin.get_rotation() \n
		Sets the rotation direction of the antenna. \n
			:return: rotation: CW| CCW
		"""
		response = self._core.io.query_str('SCAN:SIN:ROTation?')
		return Conversions.str_to_scalar_enum(response, enums.Rotation)

	def set_rotation(self, rotation: enums.Rotation) -> None:
		"""SCPI: SCAN:SIN:ROTation \n
		Snippet: driver.scan.sin.set_rotation(rotation = enums.Rotation.CCW) \n
		Sets the rotation direction of the antenna. \n
			:param rotation: CW| CCW
		"""
		param = Conversions.enum_scalar_to_str(rotation, enums.Rotation)
		self._core.io.write(f'SCAN:SIN:ROTation {param}')

	def get_uni_direction(self) -> bool:
		"""SCPI: SCAN:SIN:UNIDirection \n
		Snippet: value: bool = driver.scan.sin.get_uni_direction() \n
		Enables a unidirectional scan mode. \n
			:return: uni_direction: ON| OFF| 1| 0
		"""
		response = self._core.io.query_str('SCAN:SIN:UNIDirection?')
		return Conversions.str_to_bool(response)

	def set_uni_direction(self, uni_direction: bool) -> None:
		"""SCPI: SCAN:SIN:UNIDirection \n
		Snippet: driver.scan.sin.set_uni_direction(uni_direction = False) \n
		Enables a unidirectional scan mode. \n
			:param uni_direction: ON| OFF| 1| 0
		"""
		param = Conversions.bool_to_str(uni_direction)
		self._core.io.write(f'SCAN:SIN:UNIDirection {param}')

	def get_width(self) -> float:
		"""SCPI: SCAN:SIN:WIDTh \n
		Snippet: value: float = driver.scan.sin.get_width() \n
		Sets the angle on the XY plane between the origin and the end of the scan. \n
			:return: width: float Range: 1 to 180
		"""
		response = self._core.io.query_str('SCAN:SIN:WIDTh?')
		return Conversions.str_to_float(response)

	def set_width(self, width: float) -> None:
		"""SCPI: SCAN:SIN:WIDTh \n
		Snippet: driver.scan.sin.set_width(width = 1.0) \n
		Sets the angle on the XY plane between the origin and the end of the scan. \n
			:param width: float Range: 1 to 180
		"""
		param = Conversions.decimal_value_to_str(width)
		self._core.io.write(f'SCAN:SIN:WIDTh {param}')



from ...Internal.Core import Core
from ...Internal.CommandsGroup import CommandsGroup
from ...Internal import Conversions
from ... import enums


# noinspection PyPep8Naming,PyAttributeOutsideInit,SpellCheckingInspection
class Pmod:
	"""Pmod commands group definition. 2 total commands, 0 Subgroups, 2 group commands"""

	def __init__(self, core: Core, parent):
		self._core = core
		self._cmd_group = CommandsGroup("pmod", core, parent)

	# noinspection PyTypeChecker
	def get_direction(self) -> enums.SourceInt:
		"""SCPI: SETup:PMOD:DIRection \n
		Snippet: value: enums.SourceInt = driver.setup.pmod.get_direction() \n
		No command help available \n
			:return: direction: No help available
		"""
		response = self._core.io.query_str('SETup:PMOD:DIRection?')
		return Conversions.str_to_scalar_enum(response, enums.SourceInt)

	def set_direction(self, direction: enums.SourceInt) -> None:
		"""SCPI: SETup:PMOD:DIRection \n
		Snippet: driver.setup.pmod.set_direction(direction = enums.SourceInt.EXTernal) \n
		No command help available \n
			:param direction: No help available
		"""
		param = Conversions.enum_scalar_to_str(direction, enums.SourceInt)
		self._core.io.write(f'SETup:PMOD:DIRection {param}')

	def get_enable(self) -> bool:
		"""SCPI: SETup:PMOD:ENABle \n
		Snippet: value: bool = driver.setup.pmod.get_enable() \n
		Enables the activation of the pulse modulator for improving the on/off ratio. \n
			:return: enable: ON| OFF| 1| 0
		"""
		response = self._core.io.query_str('SETup:PMOD:ENABle?')
		return Conversions.str_to_bool(response)

	def set_enable(self, enable: bool) -> None:
		"""SCPI: SETup:PMOD:ENABle \n
		Snippet: driver.setup.pmod.set_enable(enable = False) \n
		Enables the activation of the pulse modulator for improving the on/off ratio. \n
			:param enable: ON| OFF| 1| 0
		"""
		param = Conversions.bool_to_str(enable)
		self._core.io.write(f'SETup:PMOD:ENABle {param}')



from ....Internal.Core import Core
from ....Internal.CommandsGroup import CommandsGroup
from ....Internal import Conversions
from .... import enums


# noinspection PyPep8Naming,PyAttributeOutsideInit,SpellCheckingInspection
class Model:
	"""Model commands group definition. 57 total commands, 13 Subgroups, 4 group commands"""

	def __init__(self, core: Core, parent):
		self._core = core
		self._cmd_group = CommandsGroup("model", core, parent)

	@property
	def array(self):
		"""array commands group. 1 Sub-classes, 7 commands."""
		if not hasattr(self, '_array'):
			from .Array import Array
			self._array = Array(self._core, self._cmd_group)
		return self._array

	@property
	def backlobe(self):
		"""backlobe commands group. 0 Sub-classes, 3 commands."""
		if not hasattr(self, '_backlobe'):
			from .Backlobe import Backlobe
			self._backlobe = Backlobe(self._core, self._cmd_group)
		return self._backlobe

	@property
	def cardoid(self):
		"""cardoid commands group. 0 Sub-classes, 1 commands."""
		if not hasattr(self, '_cardoid'):
			from .Cardoid import Cardoid
			self._cardoid = Cardoid(self._core, self._cmd_group)
		return self._cardoid

	@property
	def carray(self):
		"""carray commands group. 5 Sub-classes, 4 commands."""
		if not hasattr(self, '_carray'):
			from .Carray import Carray
			self._carray = Carray(self._core, self._cmd_group)
		return self._carray

	@property
	def cosecant(self):
		"""cosecant commands group. 0 Sub-classes, 3 commands."""
		if not hasattr(self, '_cosecant'):
			from .Cosecant import Cosecant
			self._cosecant = Cosecant(self._core, self._cmd_group)
		return self._cosecant

	@property
	def custom(self):
		"""custom commands group. 1 Sub-classes, 3 commands."""
		if not hasattr(self, '_custom'):
			from .Custom import Custom
			self._custom = Custom(self._core, self._cmd_group)
		return self._custom

	@property
	def gaussian(self):
		"""gaussian commands group. 1 Sub-classes, 0 commands."""
		if not hasattr(self, '_gaussian'):
			from .Gaussian import Gaussian
			self._gaussian = Gaussian(self._core, self._cmd_group)
		return self._gaussian

	@property
	def horn(self):
		"""horn commands group. 0 Sub-classes, 2 commands."""
		if not hasattr(self, '_horn'):
			from .Horn import Horn
			self._horn = Horn(self._core, self._cmd_group)
		return self._horn

	@property
	def parabolic(self):
		"""parabolic commands group. 0 Sub-classes, 1 commands."""
		if not hasattr(self, '_parabolic'):
			from .Parabolic import Parabolic
			self._parabolic = Parabolic(self._core, self._cmd_group)
		return self._parabolic

	@property
	def plugin(self):
		"""plugin commands group. 1 Sub-classes, 1 commands."""
		if not hasattr(self, '_plugin'):
			from .Plugin import Plugin
			self._plugin = Plugin(self._core, self._cmd_group)
		return self._plugin

	@property
	def rotation(self):
		"""rotation commands group. 0 Sub-classes, 2 commands."""
		if not hasattr(self, '_rotation'):
			from .Rotation import Rotation
			self._rotation = Rotation(self._core, self._cmd_group)
		return self._rotation

	@property
	def sinc(self):
		"""sinc commands group. 1 Sub-classes, 0 commands."""
		if not hasattr(self, '_sinc'):
			from .Sinc import Sinc
			self._sinc = Sinc(self._core, self._cmd_group)
		return self._sinc

	@property
	def user(self):
		"""user commands group. 1 Sub-classes, 2 commands."""
		if not hasattr(self, '_user'):
			from .User import User
			self._user = User(self._core, self._cmd_group)
		return self._user

	def get_bandwidth(self) -> float:
		"""SCPI: ANTenna:MODel:BANDwidth \n
		Snippet: value: float = driver.antenna.model.get_bandwidth() \n
		Sets the antenna bandwidth. \n
			:return: bandwidth: float Range: 1e+06 to 1e+11
		"""
		response = self._core.io.query_str('ANTenna:MODel:BANDwidth?')
		return Conversions.str_to_float(response)

	def set_bandwidth(self, bandwidth: float) -> None:
		"""SCPI: ANTenna:MODel:BANDwidth \n
		Snippet: driver.antenna.model.set_bandwidth(bandwidth = 1.0) \n
		Sets the antenna bandwidth. \n
			:param bandwidth: float Range: 1e+06 to 1e+11
		"""
		param = Conversions.decimal_value_to_str(bandwidth)
		self._core.io.write(f'ANTenna:MODel:BANDwidth {param}')

	def get_frequency(self) -> float:
		"""SCPI: ANTenna:MODel:FREQuency \n
		Snippet: value: float = driver.antenna.model.get_frequency() \n
		Sets the frequency. \n
			:return: frequency: float Range: 1e+06 to 1e+11, Unit: Hz
		"""
		response = self._core.io.query_str('ANTenna:MODel:FREQuency?')
		return Conversions.str_to_float(response)

	def set_frequency(self, frequency: float) -> None:
		"""SCPI: ANTenna:MODel:FREQuency \n
		Snippet: driver.antenna.model.set_frequency(frequency = 1.0) \n
		Sets the frequency. \n
			:param frequency: float Range: 1e+06 to 1e+11, Unit: Hz
		"""
		param = Conversions.decimal_value_to_str(frequency)
		self._core.io.write(f'ANTenna:MODel:FREQuency {param}')

	# noinspection PyTypeChecker
	def get_polarization(self) -> enums.Polarization:
		"""SCPI: ANTenna:MODel:POLarization \n
		Snippet: value: enums.Polarization = driver.antenna.model.get_polarization() \n
		Sets the antenna polarization. \n
			:return: polarization: VERTical| HORizontal| CRIGht| CLEFt| SRIGht| SLEFt
		"""
		response = self._core.io.query_str('ANTenna:MODel:POLarization?')
		return Conversions.str_to_scalar_enum(response, enums.Polarization)

	def set_polarization(self, polarization: enums.Polarization) -> None:
		"""SCPI: ANTenna:MODel:POLarization \n
		Snippet: driver.antenna.model.set_polarization(polarization = enums.Polarization.CLEFt) \n
		Sets the antenna polarization. \n
			:param polarization: VERTical| HORizontal| CRIGht| CLEFt| SRIGht| SLEFt
		"""
		param = Conversions.enum_scalar_to_str(polarization, enums.Polarization)
		self._core.io.write(f'ANTenna:MODel:POLarization {param}')

	# noinspection PyTypeChecker
	def get_type_py(self) -> enums.AntennaModel:
		"""SCPI: ANTenna:MODel:TYPE \n
		Snippet: value: enums.AntennaModel = driver.antenna.model.get_type_py() \n
		Sets the antenna pattern. \n
			:return: type_py: DIPole| PARabolic| GAUSsian| SINC| HORN| COSecant| ARRay| USER| CUSTom| CARRay| CARDoid| PLUGin
		"""
		response = self._core.io.query_str('ANTenna:MODel:TYPE?')
		return Conversions.str_to_scalar_enum(response, enums.AntennaModel)

	def set_type_py(self, type_py: enums.AntennaModel) -> None:
		"""SCPI: ANTenna:MODel:TYPE \n
		Snippet: driver.antenna.model.set_type_py(type_py = enums.AntennaModel.ARRay) \n
		Sets the antenna pattern. \n
			:param type_py: DIPole| PARabolic| GAUSsian| SINC| HORN| COSecant| ARRay| USER| CUSTom| CARRay| CARDoid| PLUGin
		"""
		param = Conversions.enum_scalar_to_str(type_py, enums.AntennaModel)
		self._core.io.write(f'ANTenna:MODel:TYPE {param}')

	def clone(self) -> 'Model':
		"""Clones the group by creating new object from it and its whole existing subgroups
		Also copies all the existing default Repeated Capabilities setting,
		which you can change independently without affecting the original group"""
		new_group = Model(self._core, self._cmd_group.parent)
		self._cmd_group.synchronize_repcaps(new_group)
		return new_group



from ...Internal.Core import Core
from ...Internal.CommandsGroup import CommandsGroup
from ...Internal import Conversions
from ...Internal.Utilities import trim_str_response
from ... import enums


# noinspection PyPep8Naming,PyAttributeOutsideInit,SpellCheckingInspection
class Waveform:
	"""Waveform commands group definition. 28 total commands, 8 Subgroups, 8 group commands"""

	def __init__(self, core: Core, parent):
		self._core = core
		self._cmd_group = CommandsGroup("waveform", core, parent)

	@property
	def bemitter(self):
		"""bemitter commands group. 3 Sub-classes, 3 commands."""
		if not hasattr(self, '_bemitter'):
			from .Bemitter import Bemitter
			self._bemitter = Bemitter(self._core, self._cmd_group)
		return self._bemitter

	@property
	def iq(self):
		"""iq commands group. 0 Sub-classes, 1 commands."""
		if not hasattr(self, '_iq'):
			from .Iq import Iq
			self._iq = Iq(self._core, self._cmd_group)
		return self._iq

	@property
	def level(self):
		"""level commands group. 0 Sub-classes, 1 commands."""
		if not hasattr(self, '_level'):
			from .Level import Level
			self._level = Level(self._core, self._cmd_group)
		return self._level

	@property
	def mt(self):
		"""mt commands group. 0 Sub-classes, 2 commands."""
		if not hasattr(self, '_mt'):
			from .Mt import Mt
			self._mt = Mt(self._core, self._cmd_group)
		return self._mt

	@property
	def noise(self):
		"""noise commands group. 0 Sub-classes, 1 commands."""
		if not hasattr(self, '_noise'):
			from .Noise import Noise
			self._noise = Noise(self._core, self._cmd_group)
		return self._noise

	@property
	def pdw(self):
		"""pdw commands group. 0 Sub-classes, 1 commands."""
		if not hasattr(self, '_pdw'):
			from .Pdw import Pdw
			self._pdw = Pdw(self._core, self._cmd_group)
		return self._pdw

	@property
	def view(self):
		"""view commands group. 1 Sub-classes, 2 commands."""
		if not hasattr(self, '_view'):
			from .View import View
			self._view = View(self._core, self._cmd_group)
		return self._view

	@property
	def waveform(self):
		"""waveform commands group. 0 Sub-classes, 2 commands."""
		if not hasattr(self, '_waveform'):
			from .Waveform import Waveform
			self._waveform = Waveform(self._core, self._cmd_group)
		return self._waveform

	def get_catalog(self) -> str:
		"""SCPI: WAVeform:CATalog \n
		Snippet: value: str = driver.waveform.get_catalog() \n
		Queries the available repository elements in the database. \n
			:return: catalog: string
		"""
		response = self._core.io.query_str('WAVeform:CATalog?')
		return trim_str_response(response)

	def get_comment(self) -> str:
		"""SCPI: WAVeform:COMMent \n
		Snippet: value: str = driver.waveform.get_comment() \n
		Adds a description to the selected repository element. \n
			:return: comment: string
		"""
		response = self._core.io.query_str('WAVeform:COMMent?')
		return trim_str_response(response)

	def set_comment(self, comment: str) -> None:
		"""SCPI: WAVeform:COMMent \n
		Snippet: driver.waveform.set_comment(comment = '1') \n
		Adds a description to the selected repository element. \n
			:param comment: string
		"""
		param = Conversions.value_to_quoted_str(comment)
		self._core.io.write(f'WAVeform:COMMent {param}')

	def set_create(self, create: str) -> None:
		"""SCPI: WAVeform:CREate \n
		Snippet: driver.waveform.set_create(create = '1') \n
		Creates a repository element with the selected name. \n
			:param create: string Must be unique for the particular type of repository elements. May contain empty spaces.
		"""
		param = Conversions.value_to_quoted_str(create)
		self._core.io.write(f'WAVeform:CREate {param}')

	def get_name(self) -> str:
		"""SCPI: WAVeform:NAME \n
		Snippet: value: str = driver.waveform.get_name() \n
		Renames the selected repository element. \n
			:return: name: string Must be unique for the particular type of repository elements. May contain empty spaces.
		"""
		response = self._core.io.query_str('WAVeform:NAME?')
		return trim_str_response(response)

	def set_name(self, name: str) -> None:
		"""SCPI: WAVeform:NAME \n
		Snippet: driver.waveform.set_name(name = '1') \n
		Renames the selected repository element. \n
			:param name: string Must be unique for the particular type of repository elements. May contain empty spaces.
		"""
		param = Conversions.value_to_quoted_str(name)
		self._core.io.write(f'WAVeform:NAME {param}')

	def set_remove(self, remove: str) -> None:
		"""SCPI: WAVeform:REMove \n
		Snippet: driver.waveform.set_remove(remove = '1') \n
		Removes the selected element from the workspace. The element must not reference any child elements. Remove the referenced
		elements first. \n
			:param remove: No help available
		"""
		param = Conversions.value_to_quoted_str(remove)
		self._core.io.write(f'WAVeform:REMove {param}')

	def get_select(self) -> str:
		"""SCPI: WAVeform:SELect \n
		Snippet: value: str = driver.waveform.get_select() \n
		Selects the repository element to which the subsequent commands apply. \n
			:return: select: string Element name, as defined with the ...:CREate or ...:NAME command. To query the existing elements, use the ...:CATalog? command. For example, method RsPulseSeq.Repository.catalog.
		"""
		response = self._core.io.query_str('WAVeform:SELect?')
		return trim_str_response(response)

	def set_select(self, select: str) -> None:
		"""SCPI: WAVeform:SELect \n
		Snippet: driver.waveform.set_select(select = '1') \n
		Selects the repository element to which the subsequent commands apply. \n
			:param select: string Element name, as defined with the ...:CREate or ...:NAME command. To query the existing elements, use the ...:CATalog? command. For example, method RsPulseSeq.Repository.catalog.
		"""
		param = Conversions.value_to_quoted_str(select)
		self._core.io.write(f'WAVeform:SELect {param}')

	# noinspection PyTypeChecker
	def get_sig_cont(self) -> enums.SigCont:
		"""SCPI: WAVeform:SIGCont \n
		Snippet: value: enums.SigCont = driver.waveform.get_sig_cont() \n
		Defines the waveform signal type. \n
			:return: sig_cont: PULSe| COMM
		"""
		response = self._core.io.query_str('WAVeform:SIGCont?')
		return Conversions.str_to_scalar_enum(response, enums.SigCont)

	def set_sig_cont(self, sig_cont: enums.SigCont) -> None:
		"""SCPI: WAVeform:SIGCont \n
		Snippet: driver.waveform.set_sig_cont(sig_cont = enums.SigCont.COMM) \n
		Defines the waveform signal type. \n
			:param sig_cont: PULSe| COMM
		"""
		param = Conversions.enum_scalar_to_str(sig_cont, enums.SigCont)
		self._core.io.write(f'WAVeform:SIGCont {param}')

	# noinspection PyTypeChecker
	def get_type_py(self) -> enums.WaveformType:
		"""SCPI: WAVeform:TYPE \n
		Snippet: value: enums.WaveformType = driver.waveform.get_type_py() \n
		Sets the type of the waveform. \n
			:return: type_py: CW| NOISe| WAVeform| USER| BEMitter| MT| PDW| AIF| APDW| IQDW
		"""
		response = self._core.io.query_str('WAVeform:TYPE?')
		return Conversions.str_to_scalar_enum(response, enums.WaveformType)

	def set_type_py(self, type_py: enums.WaveformType) -> None:
		"""SCPI: WAVeform:TYPE \n
		Snippet: driver.waveform.set_type_py(type_py = enums.WaveformType.AIF) \n
		Sets the type of the waveform. \n
			:param type_py: CW| NOISe| WAVeform| USER| BEMitter| MT| PDW| AIF| APDW| IQDW
		"""
		param = Conversions.enum_scalar_to_str(type_py, enums.WaveformType)
		self._core.io.write(f'WAVeform:TYPE {param}')

	def clone(self) -> 'Waveform':
		"""Clones the group by creating new object from it and its whole existing subgroups
		Also copies all the existing default Repeated Capabilities setting,
		which you can change independently without affecting the original group"""
		new_group = Waveform(self._core, self._cmd_group.parent)
		self._cmd_group.synchronize_repcaps(new_group)
		return new_group



from ...Internal.Core import Core
from ...Internal.CommandsGroup import CommandsGroup
from ...Internal import Conversions
from ... import enums


# noinspection PyPep8Naming,PyAttributeOutsideInit,SpellCheckingInspection
class Phase:
	"""Phase commands group definition. 1 total commands, 0 Subgroups, 1 group commands"""

	def __init__(self, core: Core, parent):
		self._core = core
		self._cmd_group = CommandsGroup("phase", core, parent)

	# noinspection PyTypeChecker
	def get_mode(self) -> enums.PhaseMode:
		"""SCPI: SEQuence:PHASe:MODE \n
		Snippet: value: enums.PhaseMode = driver.sequence.phase.get_mode() \n
		Defines how the phase is set at each pulse start. \n
			:return: mode: ABSolute| CONTinuous| MEMory
		"""
		response = self._core.io.query_str('SEQuence:PHASe:MODE?')
		return Conversions.str_to_scalar_enum(response, enums.PhaseMode)

	def set_mode(self, mode: enums.PhaseMode) -> None:
		"""SCPI: SEQuence:PHASe:MODE \n
		Snippet: driver.sequence.phase.set_mode(mode = enums.PhaseMode.ABSolute) \n
		Defines how the phase is set at each pulse start. \n
			:param mode: ABSolute| CONTinuous| MEMory
		"""
		param = Conversions.enum_scalar_to_str(mode, enums.PhaseMode)
		self._core.io.write(f'SEQuence:PHASe:MODE {param}')



from ....Internal.Core import Core
from ....Internal.CommandsGroup import CommandsGroup
from ....Internal import Conversions
from .... import enums


# noinspection PyPep8Naming,PyAttributeOutsideInit,SpellCheckingInspection
class Poly:
	"""Poly commands group definition. 2 total commands, 0 Subgroups, 2 group commands"""

	def __init__(self, core: Core, parent):
		self._core = core
		self._cmd_group = CommandsGroup("poly", core, parent)

	def get_length(self) -> float:
		"""SCPI: PULSe:MOP:POLY:LENGth \n
		Snippet: value: float = driver.pulse.mop.poly.get_length() \n
		Sets the polyphase length (code order) . \n
			:return: length: integer Range: 1 to 100
		"""
		response = self._core.io.query_str('PULSe:MOP:POLY:LENGth?')
		return Conversions.str_to_float(response)

	def set_length(self, length: float) -> None:
		"""SCPI: PULSe:MOP:POLY:LENGth \n
		Snippet: driver.pulse.mop.poly.set_length(length = 1.0) \n
		Sets the polyphase length (code order) . \n
			:param length: integer Range: 1 to 100
		"""
		param = Conversions.decimal_value_to_str(length)
		self._core.io.write(f'PULSe:MOP:POLY:LENGth {param}')

	# noinspection PyTypeChecker
	def get_type_py(self) -> enums.PolynomType:
		"""SCPI: PULSe:MOP:POLY:TYPE \n
		Snippet: value: enums.PolynomType = driver.pulse.mop.poly.get_type_py() \n
		Selects the modulation type. \n
			:return: type_py: FRANk| P1| P2| P3| P4
		"""
		response = self._core.io.query_str('PULSe:MOP:POLY:TYPE?')
		return Conversions.str_to_scalar_enum(response, enums.PolynomType)

	def set_type_py(self, type_py: enums.PolynomType) -> None:
		"""SCPI: PULSe:MOP:POLY:TYPE \n
		Snippet: driver.pulse.mop.poly.set_type_py(type_py = enums.PolynomType.FRANk) \n
		Selects the modulation type. \n
			:param type_py: FRANk| P1| P2| P3| P4
		"""
		param = Conversions.enum_scalar_to_str(type_py, enums.PolynomType)
		self._core.io.write(f'PULSe:MOP:POLY:TYPE {param}')



from ....Internal.Core import Core
from ....Internal.CommandsGroup import CommandsGroup
from ....Internal import Conversions


# noinspection PyPep8Naming,PyAttributeOutsideInit,SpellCheckingInspection
class Position:
	"""Position commands group definition. 5 total commands, 0 Subgroups, 5 group commands"""

	def __init__(self, core: Core, parent):
		self._core = core
		self._cmd_group = CommandsGroup("position", core, parent)

	def get_angle(self) -> float:
		"""SCPI: RECeiver:ANTenna:POSition:ANGLe \n
		Snippet: value: float = driver.receiver.antenna.position.get_angle() \n
		Sets the antenna element position as an angle offset from the X-axis. \n
			:return: angle: float Range: 0 to 360
		"""
		response = self._core.io.query_str('RECeiver:ANTenna:POSition:ANGLe?')
		return Conversions.str_to_float(response)

	def set_angle(self, angle: float) -> None:
		"""SCPI: RECeiver:ANTenna:POSition:ANGLe \n
		Snippet: driver.receiver.antenna.position.set_angle(angle = 1.0) \n
		Sets the antenna element position as an angle offset from the X-axis. \n
			:param angle: float Range: 0 to 360
		"""
		param = Conversions.decimal_value_to_str(angle)
		self._core.io.write(f'RECeiver:ANTenna:POSition:ANGLe {param}')

	def get_height(self) -> float:
		"""SCPI: RECeiver:ANTenna:POSition:HEIGht \n
		Snippet: value: float = driver.receiver.antenna.position.get_height() \n
		Sets the antenna element height, relative to the receiver origin. \n
			:return: height: float Range: -1e+06 to 1e+06
		"""
		response = self._core.io.query_str('RECeiver:ANTenna:POSition:HEIGht?')
		return Conversions.str_to_float(response)

	def set_height(self, height: float) -> None:
		"""SCPI: RECeiver:ANTenna:POSition:HEIGht \n
		Snippet: driver.receiver.antenna.position.set_height(height = 1.0) \n
		Sets the antenna element height, relative to the receiver origin. \n
			:param height: float Range: -1e+06 to 1e+06
		"""
		param = Conversions.decimal_value_to_str(height)
		self._core.io.write(f'RECeiver:ANTenna:POSition:HEIGht {param}')

	def get_radius(self) -> float:
		"""SCPI: RECeiver:ANTenna:POSition:RADius \n
		Snippet: value: float = driver.receiver.antenna.position.get_radius() \n
		Sets the distance from the antenna element to the receiver origin. \n
			:return: radius: float Range: 0 to 1e+06
		"""
		response = self._core.io.query_str('RECeiver:ANTenna:POSition:RADius?')
		return Conversions.str_to_float(response)

	def set_radius(self, radius: float) -> None:
		"""SCPI: RECeiver:ANTenna:POSition:RADius \n
		Snippet: driver.receiver.antenna.position.set_radius(radius = 1.0) \n
		Sets the distance from the antenna element to the receiver origin. \n
			:param radius: float Range: 0 to 1e+06
		"""
		param = Conversions.decimal_value_to_str(radius)
		self._core.io.write(f'RECeiver:ANTenna:POSition:RADius {param}')

	def get_x(self) -> float:
		"""SCPI: RECeiver:ANTenna:POSition:X \n
		Snippet: value: float = driver.receiver.antenna.position.get_x() \n
		Sets the antenna element position as X and Y values, relative to the receiver origin. \n
			:return: x: No help available
		"""
		response = self._core.io.query_str('RECeiver:ANTenna:POSition:X?')
		return Conversions.str_to_float(response)

	def set_x(self, x: float) -> None:
		"""SCPI: RECeiver:ANTenna:POSition:X \n
		Snippet: driver.receiver.antenna.position.set_x(x = 1.0) \n
		Sets the antenna element position as X and Y values, relative to the receiver origin. \n
			:param x: float Range: -1e+06 to 1e+06
		"""
		param = Conversions.decimal_value_to_str(x)
		self._core.io.write(f'RECeiver:ANTenna:POSition:X {param}')

	def get_y(self) -> float:
		"""SCPI: RECeiver:ANTenna:POSition:Y \n
		Snippet: value: float = driver.receiver.antenna.position.get_y() \n
		Sets the antenna element position as X and Y values, relative to the receiver origin. \n
			:return: y: float Range: -1e+06 to 1e+06
		"""
		response = self._core.io.query_str('RECeiver:ANTenna:POSition:Y?')
		return Conversions.str_to_float(response)

	def set_y(self, y: float) -> None:
		"""SCPI: RECeiver:ANTenna:POSition:Y \n
		Snippet: driver.receiver.antenna.position.set_y(y = 1.0) \n
		Sets the antenna element position as X and Y values, relative to the receiver origin. \n
			:param y: float Range: -1e+06 to 1e+06
		"""
		param = Conversions.decimal_value_to_str(y)
		self._core.io.write(f'RECeiver:ANTenna:POSition:Y {param}')



from ....Internal.Core import Core
from ....Internal.CommandsGroup import CommandsGroup
from ....Internal import Conversions
from ....Internal.Utilities import trim_str_response


# noinspection PyPep8Naming,PyAttributeOutsideInit,SpellCheckingInspection
class Path:
	"""Path commands group definition. 2 total commands, 0 Subgroups, 2 group commands"""

	def __init__(self, core: Core, parent):
		self._core = core
		self._cmd_group = CommandsGroup("path", core, parent)

	def get_list_py(self) -> str:
		"""SCPI: CPANel:UNUSed:PATH:LIST \n
		Snippet: value: str = driver.cpanel.unused.path.get_list_py() \n
		Queries the available RF paths of the selected signal generators. \n
			:return: list_py: 'Path#1','Paht#2',...
		"""
		response = self._core.io.query_str('CPANel:UNUSed:PATH:LIST?')
		return trim_str_response(response)

	def set_list_py(self, list_py: str) -> None:
		"""SCPI: CPANel:UNUSed:PATH:LIST \n
		Snippet: driver.cpanel.unused.path.set_list_py(list_py = '1') \n
		Queries the available RF paths of the selected signal generators. \n
			:param list_py: 'Path#1','Paht#2',...
		"""
		param = Conversions.value_to_quoted_str(list_py)
		self._core.io.write(f'CPANel:UNUSed:PATH:LIST {param}')

	def get_select(self) -> str:
		"""SCPI: CPANel:UNUSed:PATH:SELect \n
		Snippet: value: str = driver.cpanel.unused.path.get_select() \n
		Selects the element to which the subsequent commands apply. \n
			:return: select: string Available element as queried with the corresponding ...:LIST command. For example, method RsPulseSeq.Assignment.Generator.Path.Antenna.listPy
		"""
		response = self._core.io.query_str('CPANel:UNUSed:PATH:SELect?')
		return trim_str_response(response)

	def set_select(self, select: str) -> None:
		"""SCPI: CPANel:UNUSed:PATH:SELect \n
		Snippet: driver.cpanel.unused.path.set_select(select = '1') \n
		Selects the element to which the subsequent commands apply. \n
			:param select: string Available element as queried with the corresponding ...:LIST command. For example, method RsPulseSeq.Assignment.Generator.Path.Antenna.listPy
		"""
		param = Conversions.value_to_quoted_str(select)
		self._core.io.write(f'CPANel:UNUSed:PATH:SELect {param}')



from ....Internal.Core import Core
from ....Internal.CommandsGroup import CommandsGroup
from ....Internal import Conversions
from .... import enums


# noinspection PyPep8Naming,PyAttributeOutsideInit,SpellCheckingInspection
class Helical:
	"""Helical commands group definition. 5 total commands, 1 Subgroups, 4 group commands"""

	def __init__(self, core: Core, parent):
		self._core = core
		self._cmd_group = CommandsGroup("helical", core, parent)

	@property
	def elevation(self):
		"""elevation commands group. 0 Sub-classes, 1 commands."""
		if not hasattr(self, '_elevation'):
			from .Elevation import Elevation
			self._elevation = Elevation(self._core, self._cmd_group)
		return self._elevation

	def get_retrace(self) -> float:
		"""SCPI: SCAN:HELical:RETRace \n
		Snippet: value: float = driver.scan.helical.get_retrace() \n
		Sets the speed for the antenna to return to the initial orientation. \n
			:return: retrace: float Range: 0 to 1
		"""
		response = self._core.io.query_str('SCAN:HELical:RETRace?')
		return Conversions.str_to_float(response)

	def set_retrace(self, retrace: float) -> None:
		"""SCPI: SCAN:HELical:RETRace \n
		Snippet: driver.scan.helical.set_retrace(retrace = 1.0) \n
		Sets the speed for the antenna to return to the initial orientation. \n
			:param retrace: float Range: 0 to 1
		"""
		param = Conversions.decimal_value_to_str(retrace)
		self._core.io.write(f'SCAN:HELical:RETRace {param}')

	# noinspection PyTypeChecker
	def get_rotation(self) -> enums.Rotation:
		"""SCPI: SCAN:HELical:ROTation \n
		Snippet: value: enums.Rotation = driver.scan.helical.get_rotation() \n
		Sets the rotation direction of the antenna. \n
			:return: rotation: CW| CCW
		"""
		response = self._core.io.query_str('SCAN:HELical:ROTation?')
		return Conversions.str_to_scalar_enum(response, enums.Rotation)

	def set_rotation(self, rotation: enums.Rotation) -> None:
		"""SCPI: SCAN:HELical:ROTation \n
		Snippet: driver.scan.helical.set_rotation(rotation = enums.Rotation.CCW) \n
		Sets the rotation direction of the antenna. \n
			:param rotation: CW| CCW
		"""
		param = Conversions.enum_scalar_to_str(rotation, enums.Rotation)
		self._core.io.write(f'SCAN:HELical:ROTation {param}')

	def get_rpm(self) -> float:
		"""SCPI: SCAN:HELical:RPM \n
		Snippet: value: float = driver.scan.helical.get_rpm() \n
		Sets the rotation speed of the antenna. \n
			:return: rpm: float Range: 0.01 to 1000, Unit: degree/s
		"""
		response = self._core.io.query_str('SCAN:HELical:RPM?')
		return Conversions.str_to_float(response)

	def set_rpm(self, rpm: float) -> None:
		"""SCPI: SCAN:HELical:RPM \n
		Snippet: driver.scan.helical.set_rpm(rpm = 1.0) \n
		Sets the rotation speed of the antenna. \n
			:param rpm: float Range: 0.01 to 1000, Unit: degree/s
		"""
		param = Conversions.decimal_value_to_str(rpm)
		self._core.io.write(f'SCAN:HELical:RPM {param}')

	def get_turns(self) -> float:
		"""SCPI: SCAN:HELical:TURNs \n
		Snippet: value: float = driver.scan.helical.get_turns() \n
		Sets the number of turns. \n
			:return: turns: float Range: 1 to 30
		"""
		response = self._core.io.query_str('SCAN:HELical:TURNs?')
		return Conversions.str_to_float(response)

	def set_turns(self, turns: float) -> None:
		"""SCPI: SCAN:HELical:TURNs \n
		Snippet: driver.scan.helical.set_turns(turns = 1.0) \n
		Sets the number of turns. \n
			:param turns: float Range: 1 to 30
		"""
		param = Conversions.decimal_value_to_str(turns)
		self._core.io.write(f'SCAN:HELical:TURNs {param}')

	def clone(self) -> 'Helical':
		"""Clones the group by creating new object from it and its whole existing subgroups
		Also copies all the existing default Repeated Capabilities setting,
		which you can change independently without affecting the original group"""
		new_group = Helical(self._core, self._cmd_group.parent)
		self._cmd_group.synchronize_repcaps(new_group)
		return new_group



from .....Internal.Core import Core
from .....Internal.CommandsGroup import CommandsGroup
from .....Internal import Conversions
from ..... import enums


# noinspection PyPep8Naming,PyAttributeOutsideInit,SpellCheckingInspection
class Rectangular:
	"""Rectangular commands group definition. 5 total commands, 0 Subgroups, 5 group commands"""

	def __init__(self, core: Core, parent):
		self._core = core
		self._cmd_group = CommandsGroup("rectangular", core, parent)

	# noinspection PyTypeChecker
	def get_lattice(self) -> enums.Lattice:
		"""SCPI: ANTenna:MODel:CARRay:RECTangular:LATTice \n
		Snippet: value: enums.Lattice = driver.antenna.model.carray.rectangular.get_lattice() \n
		Sets the lattice. \n
			:return: lattice: RECTangular| TRIangular
		"""
		response = self._core.io.query_str('ANTenna:MODel:CARRay:RECTangular:LATTice?')
		return Conversions.str_to_scalar_enum(response, enums.Lattice)

	def set_lattice(self, lattice: enums.Lattice) -> None:
		"""SCPI: ANTenna:MODel:CARRay:RECTangular:LATTice \n
		Snippet: driver.antenna.model.carray.rectangular.set_lattice(lattice = enums.Lattice.RECTangular) \n
		Sets the lattice. \n
			:param lattice: RECTangular| TRIangular
		"""
		param = Conversions.enum_scalar_to_str(lattice, enums.Lattice)
		self._core.io.write(f'ANTenna:MODel:CARRay:RECTangular:LATTice {param}')

	def get_nx(self) -> float:
		"""SCPI: ANTenna:MODel:CARRay:RECTangular:NX \n
		Snippet: value: float = driver.antenna.model.carray.rectangular.get_nx() \n
		Sets the number of elements of the antenna array. \n
			:return: nx: No help available
		"""
		response = self._core.io.query_str('ANTenna:MODel:CARRay:RECTangular:NX?')
		return Conversions.str_to_float(response)

	def set_nx(self, nx: float) -> None:
		"""SCPI: ANTenna:MODel:CARRay:RECTangular:NX \n
		Snippet: driver.antenna.model.carray.rectangular.set_nx(nx = 1.0) \n
		Sets the number of elements of the antenna array. \n
			:param nx: float Range: 2 to 1000 (planar phased array; linear phase array) , 100 (rectangular phase array) , 50 (hexagonal phase array)
		"""
		param = Conversions.decimal_value_to_str(nx)
		self._core.io.write(f'ANTenna:MODel:CARRay:RECTangular:NX {param}')

	def get_nz(self) -> float:
		"""SCPI: ANTenna:MODel:CARRay:RECTangular:NZ \n
		Snippet: value: float = driver.antenna.model.carray.rectangular.get_nz() \n
		Sets the number of elements of the antenna array. \n
			:return: nz: float Range: 2 to 1000 (planar phased array; linear phase array) , 100 (rectangular phase array) , 50 (hexagonal phase array)
		"""
		response = self._core.io.query_str('ANTenna:MODel:CARRay:RECTangular:NZ?')
		return Conversions.str_to_float(response)

	def set_nz(self, nz: float) -> None:
		"""SCPI: ANTenna:MODel:CARRay:RECTangular:NZ \n
		Snippet: driver.antenna.model.carray.rectangular.set_nz(nz = 1.0) \n
		Sets the number of elements of the antenna array. \n
			:param nz: float Range: 2 to 1000 (planar phased array; linear phase array) , 100 (rectangular phase array) , 50 (hexagonal phase array)
		"""
		param = Conversions.decimal_value_to_str(nz)
		self._core.io.write(f'ANTenna:MODel:CARRay:RECTangular:NZ {param}')

	def get_xdistance(self) -> float:
		"""SCPI: ANTenna:MODel:CARRay:RECTangular:XDIStance \n
		Snippet: value: float = driver.antenna.model.carray.rectangular.get_xdistance() \n
		Sets the spacing between the elements of the array antenna. \n
			:return: xdistance: No help available
		"""
		response = self._core.io.query_str('ANTenna:MODel:CARRay:RECTangular:XDIStance?')
		return Conversions.str_to_float(response)

	def set_xdistance(self, xdistance: float) -> None:
		"""SCPI: ANTenna:MODel:CARRay:RECTangular:XDIStance \n
		Snippet: driver.antenna.model.carray.rectangular.set_xdistance(xdistance = 1.0) \n
		Sets the spacing between the elements of the array antenna. \n
			:param xdistance: float Range: 0.0001 to 1
		"""
		param = Conversions.decimal_value_to_str(xdistance)
		self._core.io.write(f'ANTenna:MODel:CARRay:RECTangular:XDIStance {param}')

	def get_zdistance(self) -> float:
		"""SCPI: ANTenna:MODel:CARRay:RECTangular:ZDIStance \n
		Snippet: value: float = driver.antenna.model.carray.rectangular.get_zdistance() \n
		Sets the spacing between the elements of the array antenna. \n
			:return: zdistance: float Range: 0.0001 to 1
		"""
		response = self._core.io.query_str('ANTenna:MODel:CARRay:RECTangular:ZDIStance?')
		return Conversions.str_to_float(response)

	def set_zdistance(self, zdistance: float) -> None:
		"""SCPI: ANTenna:MODel:CARRay:RECTangular:ZDIStance \n
		Snippet: driver.antenna.model.carray.rectangular.set_zdistance(zdistance = 1.0) \n
		Sets the spacing between the elements of the array antenna. \n
			:param zdistance: float Range: 0.0001 to 1
		"""
		param = Conversions.decimal_value_to_str(zdistance)
		self._core.io.write(f'ANTenna:MODel:CARRay:RECTangular:ZDIStance {param}')



from ....Internal.Core import Core
from ....Internal.CommandsGroup import CommandsGroup
from ....Internal import Conversions
from .... import enums


# noinspection PyPep8Naming,PyAttributeOutsideInit,SpellCheckingInspection
class View:
	"""View commands group definition. 4 total commands, 1 Subgroups, 2 group commands"""

	def __init__(self, core: Core, parent):
		self._core = core
		self._cmd_group = CommandsGroup("view", core, parent)

	@property
	def zoom(self):
		"""zoom commands group. 0 Sub-classes, 2 commands."""
		if not hasattr(self, '_zoom'):
			from .Zoom import Zoom
			self._zoom = Zoom(self._core, self._cmd_group)
		return self._zoom

	def set_xmode(self, xmode: enums.ViewXode) -> None:
		"""SCPI: WAVeform:VIEW:XMODe \n
		Snippet: driver.waveform.view.set_xmode(xmode = enums.ViewXode.SAMPles) \n
		Sets the units (time or samples) used on the x axis. \n
			:param xmode: SAMPles| TIME
		"""
		param = Conversions.enum_scalar_to_str(xmode, enums.ViewXode)
		self._core.io.write(f'WAVeform:VIEW:XMODe {param}')

	def set_ymode(self, ymode: enums.Ymode) -> None:
		"""SCPI: WAVeform:VIEW:YMODe \n
		Snippet: driver.waveform.view.set_ymode(ymode = enums.Ymode.FREQuency) \n
		Sets the view mode. \n
			:param ymode: IQ| MAGDb| MAGW| MAGV| PHASe| FREQuency| PAV
		"""
		param = Conversions.enum_scalar_to_str(ymode, enums.Ymode)
		self._core.io.write(f'WAVeform:VIEW:YMODe {param}')

	def clone(self) -> 'View':
		"""Clones the group by creating new object from it and its whole existing subgroups
		Also copies all the existing default Repeated Capabilities setting,
		which you can change independently without affecting the original group"""
		new_group = View(self._core, self._cmd_group.parent)
		self._cmd_group.synchronize_repcaps(new_group)
		return new_group



from ....Internal.Core import Core
from ....Internal.CommandsGroup import CommandsGroup
from ....Internal import Conversions
from ....Internal.Utilities import trim_str_response
from .... import enums


# noinspection PyPep8Naming,PyAttributeOutsideInit,SpellCheckingInspection
class Output:
	"""Output commands group definition. 25 total commands, 7 Subgroups, 11 group commands"""

	def __init__(self, core: Core, parent):
		self._core = core
		self._cmd_group = CommandsGroup("output", core, parent)

	@property
	def arb(self):
		"""arb commands group. 1 Sub-classes, 0 commands."""
		if not hasattr(self, '_arb'):
			from .Arb import Arb
			self._arb = Arb(self._core, self._cmd_group)
		return self._arb

	@property
	def clock(self):
		"""clock commands group. 1 Sub-classes, 2 commands."""
		if not hasattr(self, '_clock'):
			from .Clock import Clock
			self._clock = Clock(self._core, self._cmd_group)
		return self._clock

	@property
	def duration(self):
		"""duration commands group. 0 Sub-classes, 2 commands."""
		if not hasattr(self, '_duration'):
			from .Duration import Duration
			self._duration = Duration(self._core, self._cmd_group)
		return self._duration

	@property
	def marker(self):
		"""marker commands group. 1 Sub-classes, 2 commands."""
		if not hasattr(self, '_marker'):
			from .Marker import Marker
			self._marker = Marker(self._core, self._cmd_group)
		return self._marker

	@property
	def recall(self):
		"""recall commands group. 0 Sub-classes, 1 commands."""
		if not hasattr(self, '_recall'):
			from .Recall import Recall
			self._recall = Recall(self._core, self._cmd_group)
		return self._recall

	@property
	def reset(self):
		"""reset commands group. 0 Sub-classes, 1 commands."""
		if not hasattr(self, '_reset'):
			from .Reset import Reset
			self._reset = Reset(self._core, self._cmd_group)
		return self._reset

	@property
	def supress(self):
		"""supress commands group. 0 Sub-classes, 1 commands."""
		if not hasattr(self, '_supress'):
			from .Supress import Supress
			self._supress = Supress(self._core, self._cmd_group)
		return self._supress

	def get_clipping(self) -> float:
		"""SCPI: SCENario:OUTPut:CLIPping \n
		Snippet: value: float = driver.scenario.output.get_clipping() \n
		Sets a maximum level to limit the dynamic range of the signal. Pulses at levels above this threshold are reduced
		(clipped) to the configured level. \n
			:return: clipping: float Range: -100 to 20, Unit: dBm
		"""
		response = self._core.io.query_str('SCENario:OUTPut:CLIPping?')
		return Conversions.str_to_float(response)

	def set_clipping(self, clipping: float) -> None:
		"""SCPI: SCENario:OUTPut:CLIPping \n
		Snippet: driver.scenario.output.set_clipping(clipping = 1.0) \n
		Sets a maximum level to limit the dynamic range of the signal. Pulses at levels above this threshold are reduced
		(clipped) to the configured level. \n
			:param clipping: float Range: -100 to 20, Unit: dBm
		"""
		param = Conversions.decimal_value_to_str(clipping)
		self._core.io.write(f'SCENario:OUTPut:CLIPping {param}')

	# noinspection PyTypeChecker
	def get_format_py(self) -> enums.OutFormat:
		"""SCPI: SCENario:OUTPut:FORMat \n
		Snippet: value: enums.OutFormat = driver.scenario.output.get_format_py() \n
		Sets the type of the generated waveform file. \n
			:return: format_py: WV| MSW
		"""
		response = self._core.io.query_str('SCENario:OUTPut:FORMat?')
		return Conversions.str_to_scalar_enum(response, enums.OutFormat)

	def set_format_py(self, format_py: enums.OutFormat) -> None:
		"""SCPI: SCENario:OUTPut:FORMat \n
		Snippet: driver.scenario.output.set_format_py(format_py = enums.OutFormat.ESEQencing) \n
		Sets the type of the generated waveform file. \n
			:param format_py: WV| MSW
		"""
		param = Conversions.enum_scalar_to_str(format_py, enums.OutFormat)
		self._core.io.write(f'SCENario:OUTPut:FORMat {param}')

	def get_frequency(self) -> float:
		"""SCPI: SCENario:OUTPut:FREQuency \n
		Snippet: value: float = driver.scenario.output.get_frequency() \n
		Sets the carrier RF frequency of the generated signal. \n
			:return: frequency: float Range: 1000 to 4.4e+10
		"""
		response = self._core.io.query_str('SCENario:OUTPut:FREQuency?')
		return Conversions.str_to_float(response)

	def set_frequency(self, frequency: float) -> None:
		"""SCPI: SCENario:OUTPut:FREQuency \n
		Snippet: driver.scenario.output.set_frequency(frequency = 1.0) \n
		Sets the carrier RF frequency of the generated signal. \n
			:param frequency: float Range: 1000 to 4.4e+10
		"""
		param = Conversions.decimal_value_to_str(frequency)
		self._core.io.write(f'SCENario:OUTPut:FREQuency {param}')

	def get_level(self) -> float:
		"""SCPI: SCENario:OUTPut:LEVel \n
		Snippet: value: float = driver.scenario.output.get_level() \n
		Sets the reference level used by the calculation of the pulse envelope. \n
			:return: level: float Range: -130 to 30
		"""
		response = self._core.io.query_str('SCENario:OUTPut:LEVel?')
		return Conversions.str_to_float(response)

	def set_level(self, level: float) -> None:
		"""SCPI: SCENario:OUTPut:LEVel \n
		Snippet: driver.scenario.output.set_level(level = 1.0) \n
		Sets the reference level used by the calculation of the pulse envelope. \n
			:param level: float Range: -130 to 30
		"""
		param = Conversions.decimal_value_to_str(level)
		self._core.io.write(f'SCENario:OUTPut:LEVel {param}')

	# noinspection PyTypeChecker
	def get_mt_mode(self) -> enums.AutoManualMode:
		"""SCPI: SCENario:OUTPut:MTMode \n
		Snippet: value: enums.AutoManualMode = driver.scenario.output.get_mt_mode() \n
		If multithreading is enabled with method RsPulseSeq.Scenario.Output.multithread, sets the mode to use for multithreading. \n
			:return: mt_mode: AUTO| MANual
		"""
		response = self._core.io.query_str('SCENario:OUTPut:MTMode?')
		return Conversions.str_to_scalar_enum(response, enums.AutoManualMode)

	def set_mt_mode(self, mt_mode: enums.AutoManualMode) -> None:
		"""SCPI: SCENario:OUTPut:MTMode \n
		Snippet: driver.scenario.output.set_mt_mode(mt_mode = enums.AutoManualMode.AUTO) \n
		If multithreading is enabled with method RsPulseSeq.Scenario.Output.multithread, sets the mode to use for multithreading. \n
			:param mt_mode: AUTO| MANual
		"""
		param = Conversions.enum_scalar_to_str(mt_mode, enums.AutoManualMode)
		self._core.io.write(f'SCENario:OUTPut:MTMode {param}')

	def get_mt_threads(self) -> float:
		"""SCPI: SCENario:OUTPut:MTTHreads \n
		Snippet: value: float = driver.scenario.output.get_mt_threads() \n
		In manual mode, sets the required number of threads for the signal calculation. \n
			:return: mt_threads: float Range: 0 to 1000
		"""
		response = self._core.io.query_str('SCENario:OUTPut:MTTHreads?')
		return Conversions.str_to_float(response)

	def set_mt_threads(self, mt_threads: float) -> None:
		"""SCPI: SCENario:OUTPut:MTTHreads \n
		Snippet: driver.scenario.output.set_mt_threads(mt_threads = 1.0) \n
		In manual mode, sets the required number of threads for the signal calculation. \n
			:param mt_threads: float Range: 0 to 1000
		"""
		param = Conversions.decimal_value_to_str(mt_threads)
		self._core.io.write(f'SCENario:OUTPut:MTTHreads {param}')

	def get_multithread(self) -> bool:
		"""SCPI: SCENario:OUTPut:MULTithread \n
		Snippet: value: bool = driver.scenario.output.get_multithread() \n
		Enable to optmize the calculation speed. \n
			:return: multithread: ON| OFF| 1| 0
		"""
		response = self._core.io.query_str('SCENario:OUTPut:MULTithread?')
		return Conversions.str_to_bool(response)

	def set_multithread(self, multithread: bool) -> None:
		"""SCPI: SCENario:OUTPut:MULTithread \n
		Snippet: driver.scenario.output.set_multithread(multithread = False) \n
		Enable to optmize the calculation speed. \n
			:param multithread: ON| OFF| 1| 0
		"""
		param = Conversions.bool_to_str(multithread)
		self._core.io.write(f'SCENario:OUTPut:MULTithread {param}')

	def get_path(self) -> str:
		"""SCPI: SCENario:OUTPut:PATH \n
		Snippet: value: str = driver.scenario.output.get_path() \n
		Sets the directory the generated waveform is stored in. \n
			:return: path: string File path
		"""
		response = self._core.io.query_str('SCENario:OUTPut:PATH?')
		return trim_str_response(response)

	def set_path(self, path: str) -> None:
		"""SCPI: SCENario:OUTPut:PATH \n
		Snippet: driver.scenario.output.set_path(path = '1') \n
		Sets the directory the generated waveform is stored in. \n
			:param path: string File path
		"""
		param = Conversions.value_to_quoted_str(path)
		self._core.io.write(f'SCENario:OUTPut:PATH {param}')

	# noinspection PyTypeChecker
	def get_run_mode(self) -> enums.RepeatMode:
		"""SCPI: SCENario:OUTPut:RUNMode \n
		Snippet: value: enums.RepeatMode = driver.scenario.output.get_run_mode() \n
		Defines the way the generated signal is processed. \n
			:return: run_mode: CONTinuous| SINGle
		"""
		response = self._core.io.query_str('SCENario:OUTPut:RUNMode?')
		return Conversions.str_to_scalar_enum(response, enums.RepeatMode)

	def set_run_mode(self, run_mode: enums.RepeatMode) -> None:
		"""SCPI: SCENario:OUTPut:RUNMode \n
		Snippet: driver.scenario.output.set_run_mode(run_mode = enums.RepeatMode.CONTinuous) \n
		Defines the way the generated signal is processed. \n
			:param run_mode: CONTinuous| SINGle
		"""
		param = Conversions.enum_scalar_to_str(run_mode, enums.RepeatMode)
		self._core.io.write(f'SCENario:OUTPut:RUNMode {param}')

	# noinspection PyTypeChecker
	def get_target(self) -> enums.TargetOut:
		"""SCPI: SCENario:OUTPut:TARGet \n
		Snippet: value: enums.TargetOut = driver.scenario.output.get_target() \n
		Defines whether the software creates an ARB file or transfers the generated waveform to a connected physical generator.
		To assign a generator, use the command method RsPulseSeq.Scenario.Generator.value. To set the name and the directory the
		ARB file is stored in, use the command method RsPulseSeq.Scenario.Output.path. \n
			:return: target: INSTrument| FILE
		"""
		response = self._core.io.query_str('SCENario:OUTPut:TARGet?')
		return Conversions.str_to_scalar_enum(response, enums.TargetOut)

	def set_target(self, target: enums.TargetOut) -> None:
		"""SCPI: SCENario:OUTPut:TARGet \n
		Snippet: driver.scenario.output.set_target(target = enums.TargetOut.FILE) \n
		Defines whether the software creates an ARB file or transfers the generated waveform to a connected physical generator.
		To assign a generator, use the command method RsPulseSeq.Scenario.Generator.value. To set the name and the directory the
		ARB file is stored in, use the command method RsPulseSeq.Scenario.Output.path. \n
			:param target: INSTrument| FILE
		"""
		param = Conversions.enum_scalar_to_str(target, enums.TargetOut)
		self._core.io.write(f'SCENario:OUTPut:TARGet {param}')

	def get_threshold(self) -> float:
		"""SCPI: SCENario:OUTPut:THReshold \n
		Snippet: value: float = driver.scenario.output.get_threshold() \n
		Sets a threshold. Pulses at levels below this threshold are omitted. \n
			:return: threshold: float Range: -100 to 0
		"""
		response = self._core.io.query_str('SCENario:OUTPut:THReshold?')
		return Conversions.str_to_float(response)

	def set_threshold(self, threshold: float) -> None:
		"""SCPI: SCENario:OUTPut:THReshold \n
		Snippet: driver.scenario.output.set_threshold(threshold = 1.0) \n
		Sets a threshold. Pulses at levels below this threshold are omitted. \n
			:param threshold: float Range: -100 to 0
		"""
		param = Conversions.decimal_value_to_str(threshold)
		self._core.io.write(f'SCENario:OUTPut:THReshold {param}')

	def clone(self) -> 'Output':
		"""Clones the group by creating new object from it and its whole existing subgroups
		Also copies all the existing default Repeated Capabilities setting,
		which you can change independently without affecting the original group"""
		new_group = Output(self._core, self._cmd_group.parent)
		self._cmd_group.synchronize_repcaps(new_group)
		return new_group



from ...Internal.Core import Core
from ...Internal.CommandsGroup import CommandsGroup
from ...Internal import Conversions


# noinspection PyPep8Naming,PyAttributeOutsideInit,SpellCheckingInspection
class Noise:
	"""Noise commands group definition. 1 total commands, 0 Subgroups, 1 group commands"""

	def __init__(self, core: Core, parent):
		self._core = core
		self._cmd_group = CommandsGroup("noise", core, parent)

	def get_bandwidth(self) -> float:
		"""SCPI: WAVeform:NOISe:BWIDth \n
		Snippet: value: float = driver.waveform.noise.get_bandwidth() \n
		Sets the bandwidth of the generated AWGN waveform. \n
			:return: bwidth: float Range: 0 to 2e+09, Unit: Hz
		"""
		response = self._core.io.query_str('WAVeform:NOISe:BWIDth?')
		return Conversions.str_to_float(response)

	def set_bandwidth(self, bwidth: float) -> None:
		"""SCPI: WAVeform:NOISe:BWIDth \n
		Snippet: driver.waveform.noise.set_bandwidth(bwidth = 1.0) \n
		Sets the bandwidth of the generated AWGN waveform. \n
			:param bwidth: float Range: 0 to 2e+09, Unit: Hz
		"""
		param = Conversions.decimal_value_to_str(bwidth)
		self._core.io.write(f'WAVeform:NOISe:BWIDth {param}')



from ...Internal.Core import Core
from ...Internal.CommandsGroup import CommandsGroup
from ...Internal import Conversions
from ... import enums


# noinspection PyPep8Naming,PyAttributeOutsideInit,SpellCheckingInspection
class IpmPlot:
	"""IpmPlot commands group definition. 2 total commands, 0 Subgroups, 2 group commands"""

	def __init__(self, core: Core, parent):
		self._core = core
		self._cmd_group = CommandsGroup("ipmPlot", core, parent)

	def set_samples(self, samples: float) -> None:
		"""SCPI: DIALog:IPMPlot:SAMPles \n
		Snippet: driver.dialog.ipmPlot.set_samples(samples = 1.0) \n
		Sets the number of values to be displayed in the preview diagram of the IPM profile. \n
			:param samples: float
		"""
		param = Conversions.decimal_value_to_str(samples)
		self._core.io.write(f'DIALog:IPMPlot:SAMPles {param}')

	def set_view(self, view: enums.IpmPlotView) -> None:
		"""SCPI: DIALog:IPMPlot:VIEW \n
		Snippet: driver.dialog.ipmPlot.set_view(view = enums.IpmPlotView.HISTogram) \n
		Defines what kind of information is represented in the IPM profile diagram. \n
			:param view: TIMeseries| HISTogram TIMeseries Visualization of the profile variation over time HISTogram Statistical representation of the relative frequency density
		"""
		param = Conversions.enum_scalar_to_str(view, enums.IpmPlotView)
		self._core.io.write(f'DIALog:IPMPlot:VIEW {param}')



from ...Internal.Core import Core
from ...Internal.CommandsGroup import CommandsGroup
from ...Internal import Conversions


# noinspection PyPep8Naming,PyAttributeOutsideInit,SpellCheckingInspection
class System:
	"""System commands group definition. 3 total commands, 1 Subgroups, 1 group commands"""

	def __init__(self, core: Core, parent):
		self._core = core
		self._cmd_group = CommandsGroup("system", core, parent)

	@property
	def error(self):
		"""error commands group. 0 Sub-classes, 2 commands."""
		if not hasattr(self, '_error'):
			from .Error import Error
			self._error = Error(self._core, self._cmd_group)
		return self._error

	def get_progress(self) -> float:
		"""SCPI: SYSTem:PROGress \n
		Snippet: value: float = driver.system.get_progress() \n
		Queries the signal generation progress status. \n
			:return: progress: float
		"""
		response = self._core.io.query_str('SYSTem:PROGress?')
		return Conversions.str_to_float(response)

	def clone(self) -> 'System':
		"""Clones the group by creating new object from it and its whole existing subgroups
		Also copies all the existing default Repeated Capabilities setting,
		which you can change independently without affecting the original group"""
		new_group = System(self._core, self._cmd_group.parent)
		self._cmd_group.synchronize_repcaps(new_group)
		return new_group



from ....Internal.Core import Core
from ....Internal.CommandsGroup import CommandsGroup
from ....Internal import Conversions


# noinspection PyPep8Naming,PyAttributeOutsideInit,SpellCheckingInspection
class Cosecant:
	"""Cosecant commands group definition. 3 total commands, 0 Subgroups, 3 group commands"""

	def __init__(self, core: Core, parent):
		self._core = core
		self._cmd_group = CommandsGroup("cosecant", core, parent)

	def get_hp_bw(self) -> float:
		"""SCPI: ANTenna:MODel:COSecant:HPBW \n
		Snippet: value: float = driver.antenna.model.cosecant.get_hp_bw() \n
		Sets the Half-Power Beam Width Cosecant Squared antenna. \n
			:return: hp_bw: float Range: 0.01 to 30
		"""
		response = self._core.io.query_str('ANTenna:MODel:COSecant:HPBW?')
		return Conversions.str_to_float(response)

	def set_hp_bw(self, hp_bw: float) -> None:
		"""SCPI: ANTenna:MODel:COSecant:HPBW \n
		Snippet: driver.antenna.model.cosecant.set_hp_bw(hp_bw = 1.0) \n
		Sets the Half-Power Beam Width Cosecant Squared antenna. \n
			:param hp_bw: float Range: 0.01 to 30
		"""
		param = Conversions.decimal_value_to_str(hp_bw)
		self._core.io.write(f'ANTenna:MODel:COSecant:HPBW {param}')

	def get_t_1(self) -> float:
		"""SCPI: ANTenna:MODel:COSecant:T1 \n
		Snippet: value: float = driver.antenna.model.cosecant.get_t_1() \n
		Sets the Theta parameters. \n
			:return: t_1: No help available
		"""
		response = self._core.io.query_str('ANTenna:MODel:COSecant:T1?')
		return Conversions.str_to_float(response)

	def set_t_1(self, t_1: float) -> None:
		"""SCPI: ANTenna:MODel:COSecant:T1 \n
		Snippet: driver.antenna.model.cosecant.set_t_1(t_1 = 1.0) \n
		Sets the Theta parameters. \n
			:param t_1: float Range: 1 to 90
		"""
		param = Conversions.decimal_value_to_str(t_1)
		self._core.io.write(f'ANTenna:MODel:COSecant:T1 {param}')

	def get_t_2(self) -> float:
		"""SCPI: ANTenna:MODel:COSecant:T2 \n
		Snippet: value: float = driver.antenna.model.cosecant.get_t_2() \n
		Sets the Theta parameters. \n
			:return: t_2: float Range: 1 to 90
		"""
		response = self._core.io.query_str('ANTenna:MODel:COSecant:T2?')
		return Conversions.str_to_float(response)

	def set_t_2(self, t_2: float) -> None:
		"""SCPI: ANTenna:MODel:COSecant:T2 \n
		Snippet: driver.antenna.model.cosecant.set_t_2(t_2 = 1.0) \n
		Sets the Theta parameters. \n
			:param t_2: float Range: 1 to 90
		"""
		param = Conversions.decimal_value_to_str(t_2)
		self._core.io.write(f'ANTenna:MODel:COSecant:T2 {param}')



from ...Internal.Core import Core
from ...Internal.CommandsGroup import CommandsGroup


# noinspection PyPep8Naming,PyAttributeOutsideInit,SpellCheckingInspection
class Program:
	"""Program commands group definition. 23 total commands, 15 Subgroups, 0 group commands"""

	def __init__(self, core: Core, parent):
		self._core = core
		self._cmd_group = CommandsGroup("program", core, parent)

	@property
	def adjustments(self):
		"""adjustments commands group. 0 Sub-classes, 1 commands."""
		if not hasattr(self, '_adjustments'):
			from .Adjustments import Adjustments
			self._adjustments = Adjustments(self._core, self._cmd_group)
		return self._adjustments

	@property
	def classPy(self):
		"""classPy commands group. 0 Sub-classes, 1 commands."""
		if not hasattr(self, '_classPy'):
			from .ClassPy import ClassPy
			self._classPy = ClassPy(self._core, self._cmd_group)
		return self._classPy

	@property
	def comment(self):
		"""comment commands group. 0 Sub-classes, 1 commands."""
		if not hasattr(self, '_comment'):
			from .Comment import Comment
			self._comment = Comment(self._core, self._cmd_group)
		return self._comment

	@property
	def gpu(self):
		"""gpu commands group. 0 Sub-classes, 1 commands."""
		if not hasattr(self, '_gpu'):
			from .Gpu import Gpu
			self._gpu = Gpu(self._core, self._cmd_group)
		return self._gpu

	@property
	def hide(self):
		"""hide commands group. 0 Sub-classes, 1 commands."""
		if not hasattr(self, '_hide'):
			from .Hide import Hide
			self._hide = Hide(self._core, self._cmd_group)
		return self._hide

	@property
	def path(self):
		"""path commands group. 0 Sub-classes, 4 commands."""
		if not hasattr(self, '_path'):
			from .Path import Path
			self._path = Path(self._core, self._cmd_group)
		return self._path

	@property
	def ramBuff(self):
		"""ramBuff commands group. 0 Sub-classes, 1 commands."""
		if not hasattr(self, '_ramBuff'):
			from .RamBuff import RamBuff
			self._ramBuff = RamBuff(self._core, self._cmd_group)
		return self._ramBuff

	@property
	def scenario(self):
		"""scenario commands group. 1 Sub-classes, 0 commands."""
		if not hasattr(self, '_scenario'):
			from .Scenario import Scenario
			self._scenario = Scenario(self._core, self._cmd_group)
		return self._scenario

	@property
	def settings(self):
		"""settings commands group. 2 Sub-classes, 0 commands."""
		if not hasattr(self, '_settings'):
			from .Settings import Settings
			self._settings = Settings(self._core, self._cmd_group)
		return self._settings

	@property
	def show(self):
		"""show commands group. 0 Sub-classes, 1 commands."""
		if not hasattr(self, '_show'):
			from .Show import Show
			self._show = Show(self._core, self._cmd_group)
		return self._show

	@property
	def startup(self):
		"""startup commands group. 2 Sub-classes, 0 commands."""
		if not hasattr(self, '_startup'):
			from .Startup import Startup
			self._startup = Startup(self._core, self._cmd_group)
		return self._startup

	@property
	def storageLoc(self):
		"""storageLoc commands group. 0 Sub-classes, 1 commands."""
		if not hasattr(self, '_storageLoc'):
			from .StorageLoc import StorageLoc
			self._storageLoc = StorageLoc(self._core, self._cmd_group)
		return self._storageLoc

	@property
	def toolbar(self):
		"""toolbar commands group. 0 Sub-classes, 1 commands."""
		if not hasattr(self, '_toolbar'):
			from .Toolbar import Toolbar
			self._toolbar = Toolbar(self._core, self._cmd_group)
		return self._toolbar

	@property
	def transfer(self):
		"""transfer commands group. 1 Sub-classes, 0 commands."""
		if not hasattr(self, '_transfer'):
			from .Transfer import Transfer
			self._transfer = Transfer(self._core, self._cmd_group)
		return self._transfer

	@property
	def tutorials(self):
		"""tutorials commands group. 1 Sub-classes, 0 commands."""
		if not hasattr(self, '_tutorials'):
			from .Tutorials import Tutorials
			self._tutorials = Tutorials(self._core, self._cmd_group)
		return self._tutorials

	def clone(self) -> 'Program':
		"""Clones the group by creating new object from it and its whole existing subgroups
		Also copies all the existing default Repeated Capabilities setting,
		which you can change independently without affecting the original group"""
		new_group = Program(self._core, self._cmd_group.parent)
		self._cmd_group.synchronize_repcaps(new_group)
		return new_group



from ....Internal.Core import Core
from ....Internal.CommandsGroup import CommandsGroup
from ....Internal import Conversions
from ....Internal.Utilities import trim_str_response


# noinspection PyPep8Naming,PyAttributeOutsideInit,SpellCheckingInspection
class Waveform:
	"""Waveform commands group definition. 6 total commands, 0 Subgroups, 6 group commands"""

	def __init__(self, core: Core, parent):
		self._core = core
		self._cmd_group = CommandsGroup("waveform", core, parent)

	def get_antenna(self) -> str:
		"""SCPI: SCENario:LOCalized:WAVeform:ANTenna \n
		Snippet: value: str = driver.scenario.localized.waveform.get_antenna() \n
		Assigns an existing antenna pattern, see method RsPulseSeq.Antenna.catalog. \n
			:return: antenna: string
		"""
		response = self._core.io.query_str('SCENario:LOCalized:WAVeform:ANTenna?')
		return trim_str_response(response)

	def set_antenna(self, antenna: str) -> None:
		"""SCPI: SCENario:LOCalized:WAVeform:ANTenna \n
		Snippet: driver.scenario.localized.waveform.set_antenna(antenna = '1') \n
		Assigns an existing antenna pattern, see method RsPulseSeq.Antenna.catalog. \n
			:param antenna: string
		"""
		param = Conversions.value_to_quoted_str(antenna)
		self._core.io.write(f'SCENario:LOCalized:WAVeform:ANTenna {param}')

	def get_eirp(self) -> float:
		"""SCPI: SCENario:LOCalized:WAVeform:EIRP \n
		Snippet: value: float = driver.scenario.localized.waveform.get_eirp() \n
		Sets the of the interferer. \n
			:return: eirp: float Range: -200 to 200
		"""
		response = self._core.io.query_str('SCENario:LOCalized:WAVeform:EIRP?')
		return Conversions.str_to_float(response)

	def set_eirp(self, eirp: float) -> None:
		"""SCPI: SCENario:LOCalized:WAVeform:EIRP \n
		Snippet: driver.scenario.localized.waveform.set_eirp(eirp = 1.0) \n
		Sets the of the interferer. \n
			:param eirp: float Range: -200 to 200
		"""
		param = Conversions.decimal_value_to_str(eirp)
		self._core.io.write(f'SCENario:LOCalized:WAVeform:EIRP {param}')

	def get_frequency(self) -> float:
		"""SCPI: SCENario:LOCalized:WAVeform:FREQuency \n
		Snippet: value: float = driver.scenario.localized.waveform.get_frequency() \n
		Sets the frequency of the interferer. \n
			:return: frequency: float Range: 1000 to 4.4e+10
		"""
		response = self._core.io.query_str('SCENario:LOCalized:WAVeform:FREQuency?')
		return Conversions.str_to_float(response)

	def set_frequency(self, frequency: float) -> None:
		"""SCPI: SCENario:LOCalized:WAVeform:FREQuency \n
		Snippet: driver.scenario.localized.waveform.set_frequency(frequency = 1.0) \n
		Sets the frequency of the interferer. \n
			:param frequency: float Range: 1000 to 4.4e+10
		"""
		param = Conversions.decimal_value_to_str(frequency)
		self._core.io.write(f'SCENario:LOCalized:WAVeform:FREQuency {param}')

	def get_level(self) -> float:
		"""SCPI: SCENario:LOCalized:WAVeform:LEVel \n
		Snippet: value: float = driver.scenario.localized.waveform.get_level() \n
		Sets the of the interferer. \n
			:return: level: No help available
		"""
		response = self._core.io.query_str('SCENario:LOCalized:WAVeform:LEVel?')
		return Conversions.str_to_float(response)

	def set_level(self, level: float) -> None:
		"""SCPI: SCENario:LOCalized:WAVeform:LEVel \n
		Snippet: driver.scenario.localized.waveform.set_level(level = 1.0) \n
		Sets the of the interferer. \n
			:param level: float Range: -200 to 200
		"""
		param = Conversions.decimal_value_to_str(level)
		self._core.io.write(f'SCENario:LOCalized:WAVeform:LEVel {param}')

	def get_scan(self) -> str:
		"""SCPI: SCENario:LOCalized:WAVeform:SCAN \n
		Snippet: value: str = driver.scenario.localized.waveform.get_scan() \n
		Assigns an existing antenna scan, see method RsPulseSeq.Scan.catalog. \n
			:return: scan: string
		"""
		response = self._core.io.query_str('SCENario:LOCalized:WAVeform:SCAN?')
		return trim_str_response(response)

	def set_scan(self, scan: str) -> None:
		"""SCPI: SCENario:LOCalized:WAVeform:SCAN \n
		Snippet: driver.scenario.localized.waveform.set_scan(scan = '1') \n
		Assigns an existing antenna scan, see method RsPulseSeq.Scan.catalog. \n
			:param scan: string
		"""
		param = Conversions.value_to_quoted_str(scan)
		self._core.io.write(f'SCENario:LOCalized:WAVeform:SCAN {param}')

	def get_value(self) -> str:
		"""SCPI: SCENario:LOCalized:WAVeform \n
		Snippet: value: str = driver.scenario.localized.waveform.get_value() \n
		Assigns an existing emitter or an existing waveform, see method RsPulseSeq.Waveform.catalog and method RsPulseSeq.Emitter.
		catalog. \n
			:return: waveform: string
		"""
		response = self._core.io.query_str('SCENario:LOCalized:WAVeform?')
		return trim_str_response(response)

	def set_value(self, waveform: str) -> None:
		"""SCPI: SCENario:LOCalized:WAVeform \n
		Snippet: driver.scenario.localized.waveform.set_value(waveform = '1') \n
		Assigns an existing emitter or an existing waveform, see method RsPulseSeq.Waveform.catalog and method RsPulseSeq.Emitter.
		catalog. \n
			:param waveform: string
		"""
		param = Conversions.value_to_quoted_str(waveform)
		self._core.io.write(f'SCENario:LOCalized:WAVeform {param}')



from .....Internal.Core import Core
from .....Internal.CommandsGroup import CommandsGroup
from .....Internal import Conversions


# noinspection PyPep8Naming,PyAttributeOutsideInit,SpellCheckingInspection
class Marker:
	"""Marker commands group definition. 7 total commands, 1 Subgroups, 3 group commands"""

	def __init__(self, core: Core, parent):
		self._core = core
		self._cmd_group = CommandsGroup("marker", core, parent)

	@property
	def condition(self):
		"""condition commands group. 0 Sub-classes, 4 commands."""
		if not hasattr(self, '_condition'):
			from .Condition import Condition
			self._condition = Condition(self._core, self._cmd_group)
		return self._condition

	def get_all(self) -> float:
		"""SCPI: SEQuence:ITEM:MARKer:ALL \n
		Snippet: value: float = driver.sequence.item.marker.get_all() \n
		Enables up to four markers of the corresponding type. \n
			:return: all_py: float See Table 'Setting parameter as function of the marker states'. Range: 0 to 65535
		"""
		response = self._core.io.query_str('SEQuence:ITEM:MARKer:ALL?')
		return Conversions.str_to_float(response)

	def set_all(self, all_py: float) -> None:
		"""SCPI: SEQuence:ITEM:MARKer:ALL \n
		Snippet: driver.sequence.item.marker.set_all(all_py = 1.0) \n
		Enables up to four markers of the corresponding type. \n
			:param all_py: float See Table 'Setting parameter as function of the marker states'. Range: 0 to 65535
		"""
		param = Conversions.decimal_value_to_str(all_py)
		self._core.io.write(f'SEQuence:ITEM:MARKer:ALL {param}')

	def get_first(self) -> float:
		"""SCPI: SEQuence:ITEM:MARKer:FIRSt \n
		Snippet: value: float = driver.sequence.item.marker.get_first() \n
		Enables up to four markers of the corresponding type. \n
			:return: first: No help available
		"""
		response = self._core.io.query_str('SEQuence:ITEM:MARKer:FIRSt?')
		return Conversions.str_to_float(response)

	def set_first(self, first: float) -> None:
		"""SCPI: SEQuence:ITEM:MARKer:FIRSt \n
		Snippet: driver.sequence.item.marker.set_first(first = 1.0) \n
		Enables up to four markers of the corresponding type. \n
			:param first: float See Table 'Setting parameter as function of the marker states'. Range: 0 to 65535
		"""
		param = Conversions.decimal_value_to_str(first)
		self._core.io.write(f'SEQuence:ITEM:MARKer:FIRSt {param}')

	def get_last(self) -> float:
		"""SCPI: SEQuence:ITEM:MARKer:LAST \n
		Snippet: value: float = driver.sequence.item.marker.get_last() \n
		Enables up to four markers of the corresponding type. \n
			:return: last: No help available
		"""
		response = self._core.io.query_str('SEQuence:ITEM:MARKer:LAST?')
		return Conversions.str_to_float(response)

	def set_last(self, last: float) -> None:
		"""SCPI: SEQuence:ITEM:MARKer:LAST \n
		Snippet: driver.sequence.item.marker.set_last(last = 1.0) \n
		Enables up to four markers of the corresponding type. \n
			:param last: float See Table 'Setting parameter as function of the marker states'. Range: 0 to 65535
		"""
		param = Conversions.decimal_value_to_str(last)
		self._core.io.write(f'SEQuence:ITEM:MARKer:LAST {param}')

	def clone(self) -> 'Marker':
		"""Clones the group by creating new object from it and its whole existing subgroups
		Also copies all the existing default Repeated Capabilities setting,
		which you can change independently without affecting the original group"""
		new_group = Marker(self._core, self._cmd_group.parent)
		self._cmd_group.synchronize_repcaps(new_group)
		return new_group



from ....Internal.Core import Core
from ....Internal.CommandsGroup import CommandsGroup
from ....Internal import Conversions
from .... import enums


# noinspection PyPep8Naming,PyAttributeOutsideInit,SpellCheckingInspection
class Fsk:
	"""Fsk commands group definition. 4 total commands, 0 Subgroups, 4 group commands"""

	def __init__(self, core: Core, parent):
		self._core = core
		self._cmd_group = CommandsGroup("fsk", core, parent)

	def get_deviation(self) -> float:
		"""SCPI: PULSe:MOP:FSK:DEViation \n
		Snippet: value: float = driver.pulse.mop.fsk.get_deviation() \n
		Sets the modulation deviation. \n
			:return: deviation: float Range: 0.001 to 1e+09, Unit: Hz
		"""
		response = self._core.io.query_str('PULSe:MOP:FSK:DEViation?')
		return Conversions.str_to_float(response)

	def set_deviation(self, deviation: float) -> None:
		"""SCPI: PULSe:MOP:FSK:DEViation \n
		Snippet: driver.pulse.mop.fsk.set_deviation(deviation = 1.0) \n
		Sets the modulation deviation. \n
			:param deviation: float Range: 0.001 to 1e+09, Unit: Hz
		"""
		param = Conversions.decimal_value_to_str(deviation)
		self._core.io.write(f'PULSe:MOP:FSK:DEViation {param}')

	def get_invert(self) -> bool:
		"""SCPI: PULSe:MOP:FSK:INVert \n
		Snippet: value: bool = driver.pulse.mop.fsk.get_invert() \n
		Inverts the modulation. \n
			:return: invert: ON| OFF| 1| 0
		"""
		response = self._core.io.query_str('PULSe:MOP:FSK:INVert?')
		return Conversions.str_to_bool(response)

	def set_invert(self, invert: bool) -> None:
		"""SCPI: PULSe:MOP:FSK:INVert \n
		Snippet: driver.pulse.mop.fsk.set_invert(invert = False) \n
		Inverts the modulation. \n
			:param invert: ON| OFF| 1| 0
		"""
		param = Conversions.bool_to_str(invert)
		self._core.io.write(f'PULSe:MOP:FSK:INVert {param}')

	def get_symbol_rate(self) -> float:
		"""SCPI: PULSe:MOP:FSK:SRATe \n
		Snippet: value: float = driver.pulse.mop.fsk.get_symbol_rate() \n
		Sets the symbol rate of the modulated signal. \n
			:return: srate: float Range: 1 to 1e+09
		"""
		response = self._core.io.query_str('PULSe:MOP:FSK:SRATe?')
		return Conversions.str_to_float(response)

	def set_symbol_rate(self, srate: float) -> None:
		"""SCPI: PULSe:MOP:FSK:SRATe \n
		Snippet: driver.pulse.mop.fsk.set_symbol_rate(srate = 1.0) \n
		Sets the symbol rate of the modulated signal. \n
			:param srate: float Range: 1 to 1e+09
		"""
		param = Conversions.decimal_value_to_str(srate)
		self._core.io.write(f'PULSe:MOP:FSK:SRATe {param}')

	# noinspection PyTypeChecker
	def get_type_py(self) -> enums.FskType:
		"""SCPI: PULSe:MOP:FSK:TYPE \n
		Snippet: value: enums.FskType = driver.pulse.mop.fsk.get_type_py() \n
		Selects the FSK modulation type. \n
			:return: type_py: FS2| FS4| FS8| FS16| FS32| FS64
		"""
		response = self._core.io.query_str('PULSe:MOP:FSK:TYPE?')
		return Conversions.str_to_scalar_enum(response, enums.FskType)

	def set_type_py(self, type_py: enums.FskType) -> None:
		"""SCPI: PULSe:MOP:FSK:TYPE \n
		Snippet: driver.pulse.mop.fsk.set_type_py(type_py = enums.FskType.FS16) \n
		Selects the FSK modulation type. \n
			:param type_py: FS2| FS4| FS8| FS16| FS32| FS64
		"""
		param = Conversions.enum_scalar_to_str(type_py, enums.FskType)
		self._core.io.write(f'PULSe:MOP:FSK:TYPE {param}')



from ....Internal.Core import Core
from ....Internal.CommandsGroup import CommandsGroup
from ....Internal import Conversions


# noinspection PyPep8Naming,PyAttributeOutsideInit,SpellCheckingInspection
class Bemitter:
	"""Bemitter commands group definition. 8 total commands, 3 Subgroups, 3 group commands"""

	def __init__(self, core: Core, parent):
		self._core = core
		self._cmd_group = CommandsGroup("bemitter", core, parent)

	@property
	def level(self):
		"""level commands group. 0 Sub-classes, 1 commands."""
		if not hasattr(self, '_level'):
			from .Level import Level
			self._level = Level(self._core, self._cmd_group)
		return self._level

	@property
	def pri(self):
		"""pri commands group. 1 Sub-classes, 0 commands."""
		if not hasattr(self, '_pri'):
			from .Pri import Pri
			self._pri = Pri(self._core, self._cmd_group)
		return self._pri

	@property
	def pw(self):
		"""pw commands group. 0 Sub-classes, 2 commands."""
		if not hasattr(self, '_pw'):
			from .Pw import Pw
			self._pw = Pw(self._core, self._cmd_group)
		return self._pw

	def get_bandwidth(self) -> float:
		"""SCPI: WAVeform:BEMitter:BWIDth \n
		Snippet: value: float = driver.waveform.bemitter.get_bandwidth() \n
		Sets the maximum permissible bandwidth of the resulting signal. \n
			:return: bwidth: float Range: 1000 to 2e+09
		"""
		response = self._core.io.query_str('WAVeform:BEMitter:BWIDth?')
		return Conversions.str_to_float(response)

	def set_bandwidth(self, bwidth: float) -> None:
		"""SCPI: WAVeform:BEMitter:BWIDth \n
		Snippet: driver.waveform.bemitter.set_bandwidth(bwidth = 1.0) \n
		Sets the maximum permissible bandwidth of the resulting signal. \n
			:param bwidth: float Range: 1000 to 2e+09
		"""
		param = Conversions.decimal_value_to_str(bwidth)
		self._core.io.write(f'WAVeform:BEMitter:BWIDth {param}')

	def get_count(self) -> float:
		"""SCPI: WAVeform:BEMitter:COUNt \n
		Snippet: value: float = driver.waveform.bemitter.get_count() \n
		Sets the number of background emitters. \n
			:return: count: integer Range: 1 to 255
		"""
		response = self._core.io.query_str('WAVeform:BEMitter:COUNt?')
		return Conversions.str_to_float(response)

	def set_count(self, count: float) -> None:
		"""SCPI: WAVeform:BEMitter:COUNt \n
		Snippet: driver.waveform.bemitter.set_count(count = 1.0) \n
		Sets the number of background emitters. \n
			:param count: integer Range: 1 to 255
		"""
		param = Conversions.decimal_value_to_str(count)
		self._core.io.write(f'WAVeform:BEMitter:COUNt {param}')

	def get_duration(self) -> float:
		"""SCPI: WAVeform:BEMitter:DURation \n
		Snippet: value: float = driver.waveform.bemitter.get_duration() \n
		Sets the signal duration. \n
			:return: duration: float Range: 0.0001 to 1
		"""
		response = self._core.io.query_str('WAVeform:BEMitter:DURation?')
		return Conversions.str_to_float(response)

	def set_duration(self, duration: float) -> None:
		"""SCPI: WAVeform:BEMitter:DURation \n
		Snippet: driver.waveform.bemitter.set_duration(duration = 1.0) \n
		Sets the signal duration. \n
			:param duration: float Range: 0.0001 to 1
		"""
		param = Conversions.decimal_value_to_str(duration)
		self._core.io.write(f'WAVeform:BEMitter:DURation {param}')

	def clone(self) -> 'Bemitter':
		"""Clones the group by creating new object from it and its whole existing subgroups
		Also copies all the existing default Repeated Capabilities setting,
		which you can change independently without affecting the original group"""
		new_group = Bemitter(self._core, self._cmd_group.parent)
		self._cmd_group.synchronize_repcaps(new_group)
		return new_group



from ...Internal.Core import Core
from ...Internal.CommandsGroup import CommandsGroup
from ...Internal import Conversions
from ... import enums


# noinspection PyPep8Naming,PyAttributeOutsideInit,SpellCheckingInspection
class Time:
	"""Time commands group definition. 6 total commands, 0 Subgroups, 6 group commands"""

	def __init__(self, core: Core, parent):
		self._core = core
		self._cmd_group = CommandsGroup("time", core, parent)

	def get_fall(self) -> float:
		"""SCPI: PULSe:TIME:FALL \n
		Snippet: value: float = driver.pulse.time.get_fall() \n
		Sets the transition time of the rising and falling edges. \n
			:return: fall: No help available
		"""
		response = self._core.io.query_str('PULSe:TIME:FALL?')
		return Conversions.str_to_float(response)

	def set_fall(self, fall: float) -> None:
		"""SCPI: PULSe:TIME:FALL \n
		Snippet: driver.pulse.time.set_fall(fall = 1.0) \n
		Sets the transition time of the rising and falling edges. \n
			:param fall: float Range: 0 to 3600
		"""
		param = Conversions.decimal_value_to_str(fall)
		self._core.io.write(f'PULSe:TIME:FALL {param}')

	def get_post(self) -> float:
		"""SCPI: PULSe:TIME:POST \n
		Snippet: value: float = driver.pulse.time.get_post() \n
		Sets the marker's duration. \n
			:return: post: float Range: 0 to 3600
		"""
		response = self._core.io.query_str('PULSe:TIME:POST?')
		return Conversions.str_to_float(response)

	def set_post(self, post: float) -> None:
		"""SCPI: PULSe:TIME:POST \n
		Snippet: driver.pulse.time.set_post(post = 1.0) \n
		Sets the marker's duration. \n
			:param post: float Range: 0 to 3600
		"""
		param = Conversions.decimal_value_to_str(post)
		self._core.io.write(f'PULSe:TIME:POST {param}')

	def get_pre(self) -> float:
		"""SCPI: PULSe:TIME:PRE \n
		Snippet: value: float = driver.pulse.time.get_pre() \n
		Sets the marker's duration. Value different than zero shifts the start of the pulse rising edge and the entire pulse. \n
			:return: pre: float Range: 0 to 3600
		"""
		response = self._core.io.query_str('PULSe:TIME:PRE?')
		return Conversions.str_to_float(response)

	def set_pre(self, pre: float) -> None:
		"""SCPI: PULSe:TIME:PRE \n
		Snippet: driver.pulse.time.set_pre(pre = 1.0) \n
		Sets the marker's duration. Value different than zero shifts the start of the pulse rising edge and the entire pulse. \n
			:param pre: float Range: 0 to 3600
		"""
		param = Conversions.decimal_value_to_str(pre)
		self._core.io.write(f'PULSe:TIME:PRE {param}')

	# noinspection PyTypeChecker
	def get_reference(self) -> enums.TimeReference:
		"""SCPI: PULSe:TIME:REFerence \n
		Snippet: value: enums.TimeReference = driver.pulse.time.get_reference() \n
		Selects a predefined envelope profile. \n
			:return: reference: VOLTage| POWer| FULL
		"""
		response = self._core.io.query_str('PULSe:TIME:REFerence?')
		return Conversions.str_to_scalar_enum(response, enums.TimeReference)

	def set_reference(self, reference: enums.TimeReference) -> None:
		"""SCPI: PULSe:TIME:REFerence \n
		Snippet: driver.pulse.time.set_reference(reference = enums.TimeReference.FULL) \n
		Selects a predefined envelope profile. \n
			:param reference: VOLTage| POWer| FULL
		"""
		param = Conversions.enum_scalar_to_str(reference, enums.TimeReference)
		self._core.io.write(f'PULSe:TIME:REFerence {param}')

	def get_rise(self) -> float:
		"""SCPI: PULSe:TIME:RISE \n
		Snippet: value: float = driver.pulse.time.get_rise() \n
		Sets the transition time of the rising and falling edges. \n
			:return: rise: float Range: 0 to 3600
		"""
		response = self._core.io.query_str('PULSe:TIME:RISE?')
		return Conversions.str_to_float(response)

	def set_rise(self, rise: float) -> None:
		"""SCPI: PULSe:TIME:RISE \n
		Snippet: driver.pulse.time.set_rise(rise = 1.0) \n
		Sets the transition time of the rising and falling edges. \n
			:param rise: float Range: 0 to 3600
		"""
		param = Conversions.decimal_value_to_str(rise)
		self._core.io.write(f'PULSe:TIME:RISE {param}')

	def get_width(self) -> float:
		"""SCPI: PULSe:TIME:WIDTh \n
		Snippet: value: float = driver.pulse.time.get_width() \n
		Sets the time during that the pulse is on top power. \n
			:return: width: float Range: 0 to 3600, Unit: s
		"""
		response = self._core.io.query_str('PULSe:TIME:WIDTh?')
		return Conversions.str_to_float(response)

	def set_width(self, width: float) -> None:
		"""SCPI: PULSe:TIME:WIDTh \n
		Snippet: driver.pulse.time.set_width(width = 1.0) \n
		Sets the time during that the pulse is on top power. \n
			:param width: float Range: 0 to 3600, Unit: s
		"""
		param = Conversions.decimal_value_to_str(width)
		self._core.io.write(f'PULSe:TIME:WIDTh {param}')



from ...Internal.Core import Core
from ...Internal.CommandsGroup import CommandsGroup
from ...Internal import Conversions
from ... import enums


# noinspection PyPep8Naming,PyAttributeOutsideInit,SpellCheckingInspection
class Raster:
	"""Raster commands group definition. 13 total commands, 0 Subgroups, 13 group commands"""

	def __init__(self, core: Core, parent):
		self._core = core
		self._cmd_group = CommandsGroup("raster", core, parent)

	def get_bars(self) -> float:
		"""SCPI: SCAN:RASTer:BARS \n
		Snippet: value: float = driver.scan.raster.get_bars() \n
		Sets the number of scanned bars (sectors) . \n
			:return: bars: float Range: 1 to 30
		"""
		response = self._core.io.query_str('SCAN:RASTer:BARS?')
		return Conversions.str_to_float(response)

	def set_bars(self, bars: float) -> None:
		"""SCPI: SCAN:RASTer:BARS \n
		Snippet: driver.scan.raster.set_bars(bars = 1.0) \n
		Sets the number of scanned bars (sectors) . \n
			:param bars: float Range: 1 to 30
		"""
		param = Conversions.decimal_value_to_str(bars)
		self._core.io.write(f'SCAN:RASTer:BARS {param}')

	def get_bar_trans_time(self) -> float:
		"""SCPI: SCAN:RASTer:BARTranstime \n
		Snippet: value: float = driver.scan.raster.get_bar_trans_time() \n
		Transition time between two bars in bidirectional scan mode. \n
			:return: bar_trans_time: float Range: 0 to 1, Unit: seconds
		"""
		response = self._core.io.query_str('SCAN:RASTer:BARTranstime?')
		return Conversions.str_to_float(response)

	def set_bar_trans_time(self, bar_trans_time: float) -> None:
		"""SCPI: SCAN:RASTer:BARTranstime \n
		Snippet: driver.scan.raster.set_bar_trans_time(bar_trans_time = 1.0) \n
		Transition time between two bars in bidirectional scan mode. \n
			:param bar_trans_time: float Range: 0 to 1, Unit: seconds
		"""
		param = Conversions.decimal_value_to_str(bar_trans_time)
		self._core.io.write(f'SCAN:RASTer:BARTranstime {param}')

	def get_bar_width(self) -> float:
		"""SCPI: SCAN:RASTer:BARWidth \n
		Snippet: value: float = driver.scan.raster.get_bar_width() \n
		Sets the distance between two consecutive scanned bars (sectors) . \n
			:return: bar_width: float Range: 0.1 to 9, Unit: m
		"""
		response = self._core.io.query_str('SCAN:RASTer:BARWidth?')
		return Conversions.str_to_float(response)

	def set_bar_width(self, bar_width: float) -> None:
		"""SCPI: SCAN:RASTer:BARWidth \n
		Snippet: driver.scan.raster.set_bar_width(bar_width = 1.0) \n
		Sets the distance between two consecutive scanned bars (sectors) . \n
			:param bar_width: float Range: 0.1 to 9, Unit: m
		"""
		param = Conversions.decimal_value_to_str(bar_width)
		self._core.io.write(f'SCAN:RASTer:BARWidth {param}')

	# noinspection PyTypeChecker
	def get_direction(self) -> enums.RasterDirection:
		"""SCPI: SCAN:RASTer:DIRection \n
		Snippet: value: enums.RasterDirection = driver.scan.raster.get_direction() \n
		Sets the scanning direction. \n
			:return: direction: HORizontal| VERTical
		"""
		response = self._core.io.query_str('SCAN:RASTer:DIRection?')
		return Conversions.str_to_scalar_enum(response, enums.RasterDirection)

	def set_direction(self, direction: enums.RasterDirection) -> None:
		"""SCPI: SCAN:RASTer:DIRection \n
		Snippet: driver.scan.raster.set_direction(direction = enums.RasterDirection.HORizontal) \n
		Sets the scanning direction. \n
			:param direction: HORizontal| VERTical
		"""
		param = Conversions.enum_scalar_to_str(direction, enums.RasterDirection)
		self._core.io.write(f'SCAN:RASTer:DIRection {param}')

	def get_flyback(self) -> float:
		"""SCPI: SCAN:RASTer:FLYBack \n
		Snippet: value: float = driver.scan.raster.get_flyback() \n
		Sets the Flyback time for the antenna working in unidirectional mode. \n
			:return: flyback: float Range: 0 to 1, Unit: s
		"""
		response = self._core.io.query_str('SCAN:RASTer:FLYBack?')
		return Conversions.str_to_float(response)

	def set_flyback(self, flyback: float) -> None:
		"""SCPI: SCAN:RASTer:FLYBack \n
		Snippet: driver.scan.raster.set_flyback(flyback = 1.0) \n
		Sets the Flyback time for the antenna working in unidirectional mode. \n
			:param flyback: float Range: 0 to 1, Unit: s
		"""
		param = Conversions.decimal_value_to_str(flyback)
		self._core.io.write(f'SCAN:RASTer:FLYBack {param}')

	def get_palmer(self) -> bool:
		"""SCPI: SCAN:RASTer:PALMer \n
		Snippet: value: bool = driver.scan.raster.get_palmer() \n
		Enables superimposing a conical scan on the current scan. \n
			:return: palmer: ON| OFF| 1| 0
		"""
		response = self._core.io.query_str('SCAN:RASTer:PALMer?')
		return Conversions.str_to_bool(response)

	def set_palmer(self, palmer: bool) -> None:
		"""SCPI: SCAN:RASTer:PALMer \n
		Snippet: driver.scan.raster.set_palmer(palmer = False) \n
		Enables superimposing a conical scan on the current scan. \n
			:param palmer: ON| OFF| 1| 0
		"""
		param = Conversions.bool_to_str(palmer)
		self._core.io.write(f'SCAN:RASTer:PALMer {param}')

	def get_prate(self) -> float:
		"""SCPI: SCAN:RASTer:PRATe \n
		Snippet: value: float = driver.scan.raster.get_prate() \n
		Sets the scan rate. \n
			:return: prate: float Range: 0.1 to 1000
		"""
		response = self._core.io.query_str('SCAN:RASTer:PRATe?')
		return Conversions.str_to_float(response)

	def set_prate(self, prate: float) -> None:
		"""SCPI: SCAN:RASTer:PRATe \n
		Snippet: driver.scan.raster.set_prate(prate = 1.0) \n
		Sets the scan rate. \n
			:param prate: float Range: 0.1 to 1000
		"""
		param = Conversions.decimal_value_to_str(prate)
		self._core.io.write(f'SCAN:RASTer:PRATe {param}')

	def get_psquint(self) -> float:
		"""SCPI: SCAN:RASTer:PSQuint \n
		Snippet: value: float = driver.scan.raster.get_psquint() \n
		Sets the squint angle. \n
			:return: psquint: float Range: 0.05 to 45
		"""
		response = self._core.io.query_str('SCAN:RASTer:PSQuint?')
		return Conversions.str_to_float(response)

	def set_psquint(self, psquint: float) -> None:
		"""SCPI: SCAN:RASTer:PSQuint \n
		Snippet: driver.scan.raster.set_psquint(psquint = 1.0) \n
		Sets the squint angle. \n
			:param psquint: float Range: 0.05 to 45
		"""
		param = Conversions.decimal_value_to_str(psquint)
		self._core.io.write(f'SCAN:RASTer:PSQuint {param}')

	def get_rate(self) -> float:
		"""SCPI: SCAN:RASTer:RATE \n
		Snippet: value: float = driver.scan.raster.get_rate() \n
		Sets the turning speed. \n
			:return: rate: float Range: 0.01 to 100000, Unit: degree/s
		"""
		response = self._core.io.query_str('SCAN:RASTer:RATE?')
		return Conversions.str_to_float(response)

	def set_rate(self, rate: float) -> None:
		"""SCPI: SCAN:RASTer:RATE \n
		Snippet: driver.scan.raster.set_rate(rate = 1.0) \n
		Sets the turning speed. \n
			:param rate: float Range: 0.01 to 100000, Unit: degree/s
		"""
		param = Conversions.decimal_value_to_str(rate)
		self._core.io.write(f'SCAN:RASTer:RATE {param}')

	def get_retrace(self) -> float:
		"""SCPI: SCAN:RASTer:RETRace \n
		Snippet: value: float = driver.scan.raster.get_retrace() \n
		Sets the speed for the antenna to return to the initial orientation. \n
			:return: retrace: float Range: 0 to 1
		"""
		response = self._core.io.query_str('SCAN:RASTer:RETRace?')
		return Conversions.str_to_float(response)

	def set_retrace(self, retrace: float) -> None:
		"""SCPI: SCAN:RASTer:RETRace \n
		Snippet: driver.scan.raster.set_retrace(retrace = 1.0) \n
		Sets the speed for the antenna to return to the initial orientation. \n
			:param retrace: float Range: 0 to 1
		"""
		param = Conversions.decimal_value_to_str(retrace)
		self._core.io.write(f'SCAN:RASTer:RETRace {param}')

	def get_rewind(self) -> bool:
		"""SCPI: SCAN:RASTer:REWind \n
		Snippet: value: bool = driver.scan.raster.get_rewind() \n
		If enabled, the antenna scans forwards and backwards. \n
			:return: rewind: ON| OFF| 1| 0
		"""
		response = self._core.io.query_str('SCAN:RASTer:REWind?')
		return Conversions.str_to_bool(response)

	def set_rewind(self, rewind: bool) -> None:
		"""SCPI: SCAN:RASTer:REWind \n
		Snippet: driver.scan.raster.set_rewind(rewind = False) \n
		If enabled, the antenna scans forwards and backwards. \n
			:param rewind: ON| OFF| 1| 0
		"""
		param = Conversions.bool_to_str(rewind)
		self._core.io.write(f'SCAN:RASTer:REWind {param}')

	def get_uni_direction(self) -> bool:
		"""SCPI: SCAN:RASTer:UNIDirection \n
		Snippet: value: bool = driver.scan.raster.get_uni_direction() \n
		Enables a unidirectional scan mode. \n
			:return: uni_direction: ON| OFF| 1| 0
		"""
		response = self._core.io.query_str('SCAN:RASTer:UNIDirection?')
		return Conversions.str_to_bool(response)

	def set_uni_direction(self, uni_direction: bool) -> None:
		"""SCPI: SCAN:RASTer:UNIDirection \n
		Snippet: driver.scan.raster.set_uni_direction(uni_direction = False) \n
		Enables a unidirectional scan mode. \n
			:param uni_direction: ON| OFF| 1| 0
		"""
		param = Conversions.bool_to_str(uni_direction)
		self._core.io.write(f'SCAN:RASTer:UNIDirection {param}')

	def get_width(self) -> float:
		"""SCPI: SCAN:RASTer:WIDTh \n
		Snippet: value: float = driver.scan.raster.get_width() \n
		Sets the width of the sector to be scanned. \n
			:return: width: float Range: 0.1 to 360, Unit: degree
		"""
		response = self._core.io.query_str('SCAN:RASTer:WIDTh?')
		return Conversions.str_to_float(response)

	def set_width(self, width: float) -> None:
		"""SCPI: SCAN:RASTer:WIDTh \n
		Snippet: driver.scan.raster.set_width(width = 1.0) \n
		Sets the width of the sector to be scanned. \n
			:param width: float Range: 0.1 to 360, Unit: degree
		"""
		param = Conversions.decimal_value_to_str(width)
		self._core.io.write(f'SCAN:RASTer:WIDTh {param}')



from ...Internal.Core import Core
from ...Internal.CommandsGroup import CommandsGroup
from ...Internal import Conversions
from ... import enums


# noinspection PyPep8Naming,PyAttributeOutsideInit,SpellCheckingInspection
class TypePy:
	"""TypePy commands group definition. 2 total commands, 0 Subgroups, 2 group commands"""

	def __init__(self, core: Core, parent):
		self._core = core
		self._cmd_group = CommandsGroup("typePy", core, parent)

	# noinspection PyTypeChecker
	def get_fall(self) -> enums.PulseType:
		"""SCPI: PULSe:TYPE:FALL \n
		Snippet: value: enums.PulseType = driver.pulse.typePy.get_fall() \n
		Sets the slope type for the rising and falling edges. \n
			:return: fall: No help available
		"""
		response = self._core.io.query_str('PULSe:TYPE:FALL?')
		return Conversions.str_to_scalar_enum(response, enums.PulseType)

	def set_fall(self, fall: enums.PulseType) -> None:
		"""SCPI: PULSe:TYPE:FALL \n
		Snippet: driver.pulse.typePy.set_fall(fall = enums.PulseType.COSine) \n
		Sets the slope type for the rising and falling edges. \n
			:param fall: LINear| COSine| RCOSine| SQRT
		"""
		param = Conversions.enum_scalar_to_str(fall, enums.PulseType)
		self._core.io.write(f'PULSe:TYPE:FALL {param}')

	# noinspection PyTypeChecker
	def get_rise(self) -> enums.PulseType:
		"""SCPI: PULSe:TYPE:RISE \n
		Snippet: value: enums.PulseType = driver.pulse.typePy.get_rise() \n
		Sets the slope type for the rising and falling edges. \n
			:return: rise: LINear| COSine| RCOSine| SQRT
		"""
		response = self._core.io.query_str('PULSe:TYPE:RISE?')
		return Conversions.str_to_scalar_enum(response, enums.PulseType)

	def set_rise(self, rise: enums.PulseType) -> None:
		"""SCPI: PULSe:TYPE:RISE \n
		Snippet: driver.pulse.typePy.set_rise(rise = enums.PulseType.COSine) \n
		Sets the slope type for the rising and falling edges. \n
			:param rise: LINear| COSine| RCOSine| SQRT
		"""
		param = Conversions.enum_scalar_to_str(rise, enums.PulseType)
		self._core.io.write(f'PULSe:TYPE:RISE {param}')



from ....Internal.Core import Core
from ....Internal.CommandsGroup import CommandsGroup
from ....Internal import Conversions


# noinspection PyPep8Naming,PyAttributeOutsideInit,SpellCheckingInspection
class Interleaving:
	"""Interleaving commands group definition. 2 total commands, 0 Subgroups, 2 group commands"""

	def __init__(self, core: Core, parent):
		self._core = core
		self._cmd_group = CommandsGroup("interleaving", core, parent)

	def get_freq_agility(self) -> bool:
		"""SCPI: SCENario:DF:INTerleaving:FREQagility \n
		Snippet: value: bool = driver.scenario.df.interleaving.get_freq_agility() \n
		Enables frequency agility in interleaving. Requires R&S SMW with firmware version 5.xx.xxx and higher. To query the
		installed firmware version of the selected instrument, use the command method RsPulseSeq.Instrument.firmware. \n
			:return: freq_agility: ON| OFF| 1| 0
		"""
		response = self._core.io.query_str('SCENario:DF:INTerleaving:FREQagility?')
		return Conversions.str_to_bool(response)

	def set_freq_agility(self, freq_agility: bool) -> None:
		"""SCPI: SCENario:DF:INTerleaving:FREQagility \n
		Snippet: driver.scenario.df.interleaving.set_freq_agility(freq_agility = False) \n
		Enables frequency agility in interleaving. Requires R&S SMW with firmware version 5.xx.xxx and higher. To query the
		installed firmware version of the selected instrument, use the command method RsPulseSeq.Instrument.firmware. \n
			:param freq_agility: ON| OFF| 1| 0
		"""
		param = Conversions.bool_to_str(freq_agility)
		self._core.io.write(f'SCENario:DF:INTerleaving:FREQagility {param}')

	def get_value(self) -> bool:
		"""SCPI: SCENario:DF:INTerleaving \n
		Snippet: value: bool = driver.scenario.df.interleaving.get_value() \n
		If enabled, multiple PDW lists are interleaved into a single output file using a priority-based dropping algorithm. Set
		the priority with the command method RsPulseSeq.Scenario.Cpdw.priority. \n
			:return: interleaving: ON| OFF| 1| 0
		"""
		response = self._core.io.query_str('SCENario:DF:INTerleaving?')
		return Conversions.str_to_bool(response)

	def set_value(self, interleaving: bool) -> None:
		"""SCPI: SCENario:DF:INTerleaving \n
		Snippet: driver.scenario.df.interleaving.set_value(interleaving = False) \n
		If enabled, multiple PDW lists are interleaved into a single output file using a priority-based dropping algorithm. Set
		the priority with the command method RsPulseSeq.Scenario.Cpdw.priority. \n
			:param interleaving: ON| OFF| 1| 0
		"""
		param = Conversions.bool_to_str(interleaving)
		self._core.io.write(f'SCENario:DF:INTerleaving {param}')



from .....Internal.Core import Core
from .....Internal.CommandsGroup import CommandsGroup
from .....Internal import Conversions
from ..... import enums


# noinspection PyPep8Naming,PyAttributeOutsideInit,SpellCheckingInspection
class Exclude:
	"""Exclude commands group definition. 6 total commands, 2 Subgroups, 2 group commands"""

	def __init__(self, core: Core, parent):
		self._core = core
		self._cmd_group = CommandsGroup("exclude", core, parent)

	@property
	def level(self):
		"""level commands group. 0 Sub-classes, 2 commands."""
		if not hasattr(self, '_level'):
			from .Level import Level
			self._level = Level(self._core, self._cmd_group)
		return self._level

	@property
	def time(self):
		"""time commands group. 0 Sub-classes, 2 commands."""
		if not hasattr(self, '_time'):
			from .Time import Time
			self._time = Time(self._core, self._cmd_group)
		return self._time

	def get_enable(self) -> bool:
		"""SCPI: PULSe:MOP:EXCLude:ENABle \n
		Snippet: value: bool = driver.pulse.mop.exclude.get_enable() \n
		Activates the restriction of the modulation. \n
			:return: enable: ON| OFF| 1| 0
		"""
		response = self._core.io.query_str('PULSe:MOP:EXCLude:ENABle?')
		return Conversions.str_to_bool(response)

	def set_enable(self, enable: bool) -> None:
		"""SCPI: PULSe:MOP:EXCLude:ENABle \n
		Snippet: driver.pulse.mop.exclude.set_enable(enable = False) \n
		Activates the restriction of the modulation. \n
			:param enable: ON| OFF| 1| 0
		"""
		param = Conversions.bool_to_str(enable)
		self._core.io.write(f'PULSe:MOP:EXCLude:ENABle {param}')

	# noinspection PyTypeChecker
	def get_mode(self) -> enums.ExcMode:
		"""SCPI: PULSe:MOP:EXCLude:MODE \n
		Snippet: value: enums.ExcMode = driver.pulse.mop.exclude.get_mode() \n
		Selects the parameter that determines the area on that the MOP is applied. \n
			:return: mode: TIME| LEVel| WIDTh
		"""
		response = self._core.io.query_str('PULSe:MOP:EXCLude:MODE?')
		return Conversions.str_to_scalar_enum(response, enums.ExcMode)

	def set_mode(self, mode: enums.ExcMode) -> None:
		"""SCPI: PULSe:MOP:EXCLude:MODE \n
		Snippet: driver.pulse.mop.exclude.set_mode(mode = enums.ExcMode.LEVel) \n
		Selects the parameter that determines the area on that the MOP is applied. \n
			:param mode: TIME| LEVel| WIDTh
		"""
		param = Conversions.enum_scalar_to_str(mode, enums.ExcMode)
		self._core.io.write(f'PULSe:MOP:EXCLude:MODE {param}')

	def clone(self) -> 'Exclude':
		"""Clones the group by creating new object from it and its whole existing subgroups
		Also copies all the existing default Repeated Capabilities setting,
		which you can change independently without affecting the original group"""
		new_group = Exclude(self._core, self._cmd_group.parent)
		self._cmd_group.synchronize_repcaps(new_group)
		return new_group



from ...Internal.Core import Core
from ...Internal.CommandsGroup import CommandsGroup
from ...Internal import Conversions


# noinspection PyPep8Naming,PyAttributeOutsideInit,SpellCheckingInspection
class Sector:
	"""Sector commands group definition. 10 total commands, 0 Subgroups, 10 group commands"""

	def __init__(self, core: Core, parent):
		self._core = core
		self._cmd_group = CommandsGroup("sector", core, parent)

	def get_flyback(self) -> float:
		"""SCPI: SCAN:SECTor:FLYBack \n
		Snippet: value: float = driver.scan.sector.get_flyback() \n
		Sets the Flyback time for the antenna working in unidirectional mode. \n
			:return: flyback: float Range: 0 to 1, Unit: s
		"""
		response = self._core.io.query_str('SCAN:SECTor:FLYBack?')
		return Conversions.str_to_float(response)

	def set_flyback(self, flyback: float) -> None:
		"""SCPI: SCAN:SECTor:FLYBack \n
		Snippet: driver.scan.sector.set_flyback(flyback = 1.0) \n
		Sets the Flyback time for the antenna working in unidirectional mode. \n
			:param flyback: float Range: 0 to 1, Unit: s
		"""
		param = Conversions.decimal_value_to_str(flyback)
		self._core.io.write(f'SCAN:SECTor:FLYBack {param}')

	def get_nelevation(self) -> float:
		"""SCPI: SCAN:SECTor:NELevation \n
		Snippet: value: float = driver.scan.sector.get_nelevation() \n
		Sets the elevation angle. \n
			:return: nelevation: float Range: 0.01 to 90
		"""
		response = self._core.io.query_str('SCAN:SECTor:NELevation?')
		return Conversions.str_to_float(response)

	def set_nelevation(self, nelevation: float) -> None:
		"""SCPI: SCAN:SECTor:NELevation \n
		Snippet: driver.scan.sector.set_nelevation(nelevation = 1.0) \n
		Sets the elevation angle. \n
			:param nelevation: float Range: 0.01 to 90
		"""
		param = Conversions.decimal_value_to_str(nelevation)
		self._core.io.write(f'SCAN:SECTor:NELevation {param}')

	def get_nodding(self) -> bool:
		"""SCPI: SCAN:SECTor:NODDing \n
		Snippet: value: bool = driver.scan.sector.get_nodding() \n
		Enables superimposing a horizontal nodding on the scan. \n
			:return: nodding: ON| OFF| 1| 0
		"""
		response = self._core.io.query_str('SCAN:SECTor:NODDing?')
		return Conversions.str_to_bool(response)

	def set_nodding(self, nodding: bool) -> None:
		"""SCPI: SCAN:SECTor:NODDing \n
		Snippet: driver.scan.sector.set_nodding(nodding = False) \n
		Enables superimposing a horizontal nodding on the scan. \n
			:param nodding: ON| OFF| 1| 0
		"""
		param = Conversions.bool_to_str(nodding)
		self._core.io.write(f'SCAN:SECTor:NODDing {param}')

	def get_nrate(self) -> float:
		"""SCPI: SCAN:SECTor:NRATe \n
		Snippet: value: float = driver.scan.sector.get_nrate() \n
		Sets the elevation rate. \n
			:return: nrate: float Range: 0.01 to 2000
		"""
		response = self._core.io.query_str('SCAN:SECTor:NRATe?')
		return Conversions.str_to_float(response)

	def set_nrate(self, nrate: float) -> None:
		"""SCPI: SCAN:SECTor:NRATe \n
		Snippet: driver.scan.sector.set_nrate(nrate = 1.0) \n
		Sets the elevation rate. \n
			:param nrate: float Range: 0.01 to 2000
		"""
		param = Conversions.decimal_value_to_str(nrate)
		self._core.io.write(f'SCAN:SECTor:NRATe {param}')

	def get_palmer(self) -> bool:
		"""SCPI: SCAN:SECTor:PALMer \n
		Snippet: value: bool = driver.scan.sector.get_palmer() \n
		Enables superimposing a conical scan on the current scan. \n
			:return: palmer: ON| OFF| 1| 0
		"""
		response = self._core.io.query_str('SCAN:SECTor:PALMer?')
		return Conversions.str_to_bool(response)

	def set_palmer(self, palmer: bool) -> None:
		"""SCPI: SCAN:SECTor:PALMer \n
		Snippet: driver.scan.sector.set_palmer(palmer = False) \n
		Enables superimposing a conical scan on the current scan. \n
			:param palmer: ON| OFF| 1| 0
		"""
		param = Conversions.bool_to_str(palmer)
		self._core.io.write(f'SCAN:SECTor:PALMer {param}')

	def get_prate(self) -> float:
		"""SCPI: SCAN:SECTor:PRATe \n
		Snippet: value: float = driver.scan.sector.get_prate() \n
		Sets the scan rate. \n
			:return: prate: float Range: 0.1 to 1000
		"""
		response = self._core.io.query_str('SCAN:SECTor:PRATe?')
		return Conversions.str_to_float(response)

	def set_prate(self, prate: float) -> None:
		"""SCPI: SCAN:SECTor:PRATe \n
		Snippet: driver.scan.sector.set_prate(prate = 1.0) \n
		Sets the scan rate. \n
			:param prate: float Range: 0.1 to 1000
		"""
		param = Conversions.decimal_value_to_str(prate)
		self._core.io.write(f'SCAN:SECTor:PRATe {param}')

	def get_psquint(self) -> float:
		"""SCPI: SCAN:SECTor:PSQuint \n
		Snippet: value: float = driver.scan.sector.get_psquint() \n
		Sets the squint angle. \n
			:return: psquint: float Range: 0.05 to 45
		"""
		response = self._core.io.query_str('SCAN:SECTor:PSQuint?')
		return Conversions.str_to_float(response)

	def set_psquint(self, psquint: float) -> None:
		"""SCPI: SCAN:SECTor:PSQuint \n
		Snippet: driver.scan.sector.set_psquint(psquint = 1.0) \n
		Sets the squint angle. \n
			:param psquint: float Range: 0.05 to 45
		"""
		param = Conversions.decimal_value_to_str(psquint)
		self._core.io.write(f'SCAN:SECTor:PSQuint {param}')

	def get_rate(self) -> float:
		"""SCPI: SCAN:SECTor:RATE \n
		Snippet: value: float = driver.scan.sector.get_rate() \n
		Sets the turning speed. \n
			:return: rate: float Range: 0.01 to 100000, Unit: degree/s
		"""
		response = self._core.io.query_str('SCAN:SECTor:RATE?')
		return Conversions.str_to_float(response)

	def set_rate(self, rate: float) -> None:
		"""SCPI: SCAN:SECTor:RATE \n
		Snippet: driver.scan.sector.set_rate(rate = 1.0) \n
		Sets the turning speed. \n
			:param rate: float Range: 0.01 to 100000, Unit: degree/s
		"""
		param = Conversions.decimal_value_to_str(rate)
		self._core.io.write(f'SCAN:SECTor:RATE {param}')

	def get_uni_direction(self) -> bool:
		"""SCPI: SCAN:SECTor:UNIDirection \n
		Snippet: value: bool = driver.scan.sector.get_uni_direction() \n
		Enables a unidirectional scan mode. \n
			:return: uni_direction: ON| OFF| 1| 0
		"""
		response = self._core.io.query_str('SCAN:SECTor:UNIDirection?')
		return Conversions.str_to_bool(response)

	def set_uni_direction(self, uni_direction: bool) -> None:
		"""SCPI: SCAN:SECTor:UNIDirection \n
		Snippet: driver.scan.sector.set_uni_direction(uni_direction = False) \n
		Enables a unidirectional scan mode. \n
			:param uni_direction: ON| OFF| 1| 0
		"""
		param = Conversions.bool_to_str(uni_direction)
		self._core.io.write(f'SCAN:SECTor:UNIDirection {param}')

	def get_width(self) -> float:
		"""SCPI: SCAN:SECTor:WIDTh \n
		Snippet: value: float = driver.scan.sector.get_width() \n
		Sets the width of the sector to be scanned. \n
			:return: width: float Range: 0.1 to 360, Unit: degree
		"""
		response = self._core.io.query_str('SCAN:SECTor:WIDTh?')
		return Conversions.str_to_float(response)

	def set_width(self, width: float) -> None:
		"""SCPI: SCAN:SECTor:WIDTh \n
		Snippet: driver.scan.sector.set_width(width = 1.0) \n
		Sets the width of the sector to be scanned. \n
			:param width: float Range: 0.1 to 360, Unit: degree
		"""
		param = Conversions.decimal_value_to_str(width)
		self._core.io.write(f'SCAN:SECTor:WIDTh {param}')



from ...Internal.Core import Core
from ...Internal.CommandsGroup import CommandsGroup
from ...Internal import Conversions
from ... import enums


# noinspection PyPep8Naming,PyAttributeOutsideInit,SpellCheckingInspection
class Waveform:
	"""Waveform commands group definition. 7 total commands, 0 Subgroups, 7 group commands"""

	def __init__(self, core: Core, parent):
		self._core = core
		self._cmd_group = CommandsGroup("waveform", core, parent)

	# noinspection PyTypeChecker
	def get_base(self) -> enums.BaseDomain:
		"""SCPI: IPM:WAVeform:BASE \n
		Snippet: value: enums.BaseDomain = driver.ipm.waveform.get_base() \n
		Defines how the waveform period is defined, as a time duration or as a number of pulses. \n
			:return: base: PULSe| TIME
		"""
		response = self._core.io.query_str('IPM:WAVeform:BASE?')
		return Conversions.str_to_scalar_enum(response, enums.BaseDomain)

	def set_base(self, base: enums.BaseDomain) -> None:
		"""SCPI: IPM:WAVeform:BASE \n
		Snippet: driver.ipm.waveform.set_base(base = enums.BaseDomain.PULSe) \n
		Defines how the waveform period is defined, as a time duration or as a number of pulses. \n
			:param base: PULSe| TIME
		"""
		param = Conversions.enum_scalar_to_str(base, enums.BaseDomain)
		self._core.io.write(f'IPM:WAVeform:BASE {param}')

	def get_count(self) -> float:
		"""SCPI: IPM:WAVeform:COUNt \n
		Snippet: value: float = driver.ipm.waveform.get_count() \n
		Sets the waveform period as number of pulses. \n
			:return: count: integer Range: 1 to 1e+09
		"""
		response = self._core.io.query_str('IPM:WAVeform:COUNt?')
		return Conversions.str_to_float(response)

	def set_count(self, count: float) -> None:
		"""SCPI: IPM:WAVeform:COUNt \n
		Snippet: driver.ipm.waveform.set_count(count = 1.0) \n
		Sets the waveform period as number of pulses. \n
			:param count: integer Range: 1 to 1e+09
		"""
		param = Conversions.decimal_value_to_str(count)
		self._core.io.write(f'IPM:WAVeform:COUNt {param}')

	def get_offset(self) -> float:
		"""SCPI: IPM:WAVeform:OFFSet \n
		Snippet: value: float = driver.ipm.waveform.get_offset() \n
		Shifts the profile by the selected offset. \n
			:return: offset: float Range: -1e+09 to 1e+09
		"""
		response = self._core.io.query_str('IPM:WAVeform:OFFSet?')
		return Conversions.str_to_float(response)

	def set_offset(self, offset: float) -> None:
		"""SCPI: IPM:WAVeform:OFFSet \n
		Snippet: driver.ipm.waveform.set_offset(offset = 1.0) \n
		Shifts the profile by the selected offset. \n
			:param offset: float Range: -1e+09 to 1e+09
		"""
		param = Conversions.decimal_value_to_str(offset)
		self._core.io.write(f'IPM:WAVeform:OFFSet {param}')

	def get_period(self) -> float:
		"""SCPI: IPM:WAVeform:PERiod \n
		Snippet: value: float = driver.ipm.waveform.get_period() \n
		Sets the waveform period. \n
			:return: period: float Range: 1e-09 to 1e+09, Unit: sec
		"""
		response = self._core.io.query_str('IPM:WAVeform:PERiod?')
		return Conversions.str_to_float(response)

	def set_period(self, period: float) -> None:
		"""SCPI: IPM:WAVeform:PERiod \n
		Snippet: driver.ipm.waveform.set_period(period = 1.0) \n
		Sets the waveform period. \n
			:param period: float Range: 1e-09 to 1e+09, Unit: sec
		"""
		param = Conversions.decimal_value_to_str(period)
		self._core.io.write(f'IPM:WAVeform:PERiod {param}')

	def get_phase(self) -> float:
		"""SCPI: IPM:WAVeform:PHASe \n
		Snippet: value: float = driver.ipm.waveform.get_phase() \n
		Enables a phase offset to change the start phase of the sine wave. \n
			:return: phase: float Range: -1e+09 to 1e+09, Unit: sec
		"""
		response = self._core.io.query_str('IPM:WAVeform:PHASe?')
		return Conversions.str_to_float(response)

	def set_phase(self, phase: float) -> None:
		"""SCPI: IPM:WAVeform:PHASe \n
		Snippet: driver.ipm.waveform.set_phase(phase = 1.0) \n
		Enables a phase offset to change the start phase of the sine wave. \n
			:param phase: float Range: -1e+09 to 1e+09, Unit: sec
		"""
		param = Conversions.decimal_value_to_str(phase)
		self._core.io.write(f'IPM:WAVeform:PHASe {param}')

	def get_pkpk(self) -> float:
		"""SCPI: IPM:WAVeform:PKPK \n
		Snippet: value: float = driver.ipm.waveform.get_pkpk() \n
		Sets the value range of the linear ramp profile or the period of the sine profile. \n
			:return: pkpk: float Range: 1e-09 to 1e+09, Unit: sec
		"""
		response = self._core.io.query_str('IPM:WAVeform:PKPK?')
		return Conversions.str_to_float(response)

	def set_pkpk(self, pkpk: float) -> None:
		"""SCPI: IPM:WAVeform:PKPK \n
		Snippet: driver.ipm.waveform.set_pkpk(pkpk = 1.0) \n
		Sets the value range of the linear ramp profile or the period of the sine profile. \n
			:param pkpk: float Range: 1e-09 to 1e+09, Unit: sec
		"""
		param = Conversions.decimal_value_to_str(pkpk)
		self._core.io.write(f'IPM:WAVeform:PKPK {param}')

	# noinspection PyTypeChecker
	def get_type_py(self) -> enums.WaveformShape:
		"""SCPI: IPM:WAVeform:TYPE \n
		Snippet: value: enums.WaveformShape = driver.ipm.waveform.get_type_py() \n
		Sets the profile shape. \n
			:return: type_py: RAMP| SINE| TRIangular
		"""
		response = self._core.io.query_str('IPM:WAVeform:TYPE?')
		return Conversions.str_to_scalar_enum(response, enums.WaveformShape)

	def set_type_py(self, type_py: enums.WaveformShape) -> None:
		"""SCPI: IPM:WAVeform:TYPE \n
		Snippet: driver.ipm.waveform.set_type_py(type_py = enums.WaveformShape.RAMP) \n
		Sets the profile shape. \n
			:param type_py: RAMP| SINE| TRIangular
		"""
		param = Conversions.enum_scalar_to_str(type_py, enums.WaveformShape)
		self._core.io.write(f'IPM:WAVeform:TYPE {param}')



from .....Internal.Core import Core
from .....Internal.CommandsGroup import CommandsGroup
from .....Internal import Conversions
from .....Internal.Utilities import trim_str_response


# noinspection PyPep8Naming,PyAttributeOutsideInit,SpellCheckingInspection
class Group:
	"""Group commands group definition. 8 total commands, 1 Subgroups, 7 group commands"""

	def __init__(self, core: Core, parent):
		self._core = core
		self._cmd_group = CommandsGroup("group", core, parent)

	@property
	def add(self):
		"""add commands group. 0 Sub-classes, 1 commands."""
		if not hasattr(self, '_add'):
			from .Add import Add
			self._add = Add(self._core, self._cmd_group)
		return self._add

	def get_alias(self) -> str:
		"""SCPI: SCENario:CEMit:GROup:ALIas \n
		Snippet: value: str = driver.scenario.cemit.group.get_alias() \n
		Sets an alias name for the selected interleaving group. See also method RsPulseSeq.Assignment.Group.select. \n
			:return: alias: string
		"""
		response = self._core.io.query_str('SCENario:CEMit:GROup:ALIas?')
		return trim_str_response(response)

	def set_alias(self, alias: str) -> None:
		"""SCPI: SCENario:CEMit:GROup:ALIas \n
		Snippet: driver.scenario.cemit.group.set_alias(alias = '1') \n
		Sets an alias name for the selected interleaving group. See also method RsPulseSeq.Assignment.Group.select. \n
			:param alias: string
		"""
		param = Conversions.value_to_quoted_str(alias)
		self._core.io.write(f'SCENario:CEMit:GROup:ALIas {param}')

	def get_catalog(self) -> str:
		"""SCPI: SCENario:CEMit:GROup:CATalog \n
		Snippet: value: str = driver.scenario.cemit.group.get_catalog() \n
		Queries the alias names of the configured interleaving groups. \n
			:return: catalog: string A list of coma-separated alias names.
		"""
		response = self._core.io.query_str('SCENario:CEMit:GROup:CATalog?')
		return trim_str_response(response)

	def clear(self) -> None:
		"""SCPI: SCENario:CEMit:GROup:CLEar \n
		Snippet: driver.scenario.cemit.group.clear() \n
		Deletes all items from the list or the table. \n
		"""
		self._core.io.write(f'SCENario:CEMit:GROup:CLEar')

	def clear_with_opc(self, opc_timeout_ms: int = -1) -> None:
		"""SCPI: SCENario:CEMit:GROup:CLEar \n
		Snippet: driver.scenario.cemit.group.clear_with_opc() \n
		Deletes all items from the list or the table. \n
		Same as clear, but waits for the operation to complete before continuing further. Use the RsPulseSeq.utilities.opc_timeout_set() to set the timeout value. \n
			:param opc_timeout_ms: Maximum time to wait in milliseconds, valid only for this call."""
		self._core.io.write_with_opc(f'SCENario:CEMit:GROup:CLEar', opc_timeout_ms)

	def get_count(self) -> float:
		"""SCPI: SCENario:CEMit:GROup:COUNt \n
		Snippet: value: float = driver.scenario.cemit.group.get_count() \n
		Queries the number of existing items. \n
			:return: count: integer
		"""
		response = self._core.io.query_str('SCENario:CEMit:GROup:COUNt?')
		return Conversions.str_to_float(response)

	def delete(self, delete: float) -> None:
		"""SCPI: SCENario:CEMit:GROup:DELete \n
		Snippet: driver.scenario.cemit.group.delete(delete = 1.0) \n
		Deletes the particular item. \n
			:param delete: float
		"""
		param = Conversions.decimal_value_to_str(delete)
		self._core.io.write(f'SCENario:CEMit:GROup:DELete {param}')

	def get_select(self) -> float:
		"""SCPI: SCENario:CEMit:GROup:SELect \n
		Snippet: value: float = driver.scenario.cemit.group.get_select() \n
		Selects the item to which the subsequent commands apply. \n
			:return: select: float Item number within the range 1 to ...:COUNt. For example, method RsPulseSeq.Sequence.Item.count. Range: 1 to 4096
		"""
		response = self._core.io.query_str('SCENario:CEMit:GROup:SELect?')
		return Conversions.str_to_float(response)

	def set_select(self, select: float) -> None:
		"""SCPI: SCENario:CEMit:GROup:SELect \n
		Snippet: driver.scenario.cemit.group.set_select(select = 1.0) \n
		Selects the item to which the subsequent commands apply. \n
			:param select: float Item number within the range 1 to ...:COUNt. For example, method RsPulseSeq.Sequence.Item.count. Range: 1 to 4096
		"""
		param = Conversions.decimal_value_to_str(select)
		self._core.io.write(f'SCENario:CEMit:GROup:SELect {param}')

	def get_value(self) -> str:
		"""SCPI: SCENario:CEMit:GROup \n
		Snippet: value: str = driver.scenario.cemit.group.get_value() \n
		Assigns the emitter to one of the available interleaving groups. \n
			:return: group: string Query a list of the alias names of the existing interleaving groups with the command method RsPulseSeq.Scenario.Cpdw.Group.catalog.
		"""
		response = self._core.io.query_str('SCENario:CEMit:GROup?')
		return trim_str_response(response)

	def set_value(self, group: str) -> None:
		"""SCPI: SCENario:CEMit:GROup \n
		Snippet: driver.scenario.cemit.group.set_value(group = '1') \n
		Assigns the emitter to one of the available interleaving groups. \n
			:param group: string Query a list of the alias names of the existing interleaving groups with the command method RsPulseSeq.Scenario.Cpdw.Group.catalog.
		"""
		param = Conversions.value_to_quoted_str(group)
		self._core.io.write(f'SCENario:CEMit:GROup {param}')

	def clone(self) -> 'Group':
		"""Clones the group by creating new object from it and its whole existing subgroups
		Also copies all the existing default Repeated Capabilities setting,
		which you can change independently without affecting the original group"""
		new_group = Group(self._core, self._cmd_group.parent)
		self._cmd_group.synchronize_repcaps(new_group)
		return new_group
